# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StepRepr module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_steprepr.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StepRepr
else:
    import _StepRepr

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StepRepr.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StepRepr.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepRepr.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepRepr.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StepRepr.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StepRepr.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StepRepr.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StepRepr.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StepRepr.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StepRepr.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepRepr.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StepRepr.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StepRepr.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepRepr.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepRepr.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepRepr.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StepRepr.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StepRepr:
_StepRepr.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StepRepr.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepBasic

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_StepRepr_AssemblyComponentUsageSubstitute_Create() -> "opencascade::handle< StepRepr_AssemblyComponentUsageSubstitute >":
    return _StepRepr.Handle_StepRepr_AssemblyComponentUsageSubstitute_Create()

def Handle_StepRepr_AssemblyComponentUsageSubstitute_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_AssemblyComponentUsageSubstitute >":
    return _StepRepr.Handle_StepRepr_AssemblyComponentUsageSubstitute_DownCast(t)

def Handle_StepRepr_AssemblyComponentUsageSubstitute_IsNull(t: "opencascade::handle< StepRepr_AssemblyComponentUsageSubstitute > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_AssemblyComponentUsageSubstitute_IsNull(t)

def Handle_StepRepr_ConfigurationDesign_Create() -> "opencascade::handle< StepRepr_ConfigurationDesign >":
    return _StepRepr.Handle_StepRepr_ConfigurationDesign_Create()

def Handle_StepRepr_ConfigurationDesign_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ConfigurationDesign >":
    return _StepRepr.Handle_StepRepr_ConfigurationDesign_DownCast(t)

def Handle_StepRepr_ConfigurationDesign_IsNull(t: "opencascade::handle< StepRepr_ConfigurationDesign > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ConfigurationDesign_IsNull(t)

def Handle_StepRepr_ConfigurationEffectivity_Create() -> "opencascade::handle< StepRepr_ConfigurationEffectivity >":
    return _StepRepr.Handle_StepRepr_ConfigurationEffectivity_Create()

def Handle_StepRepr_ConfigurationEffectivity_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ConfigurationEffectivity >":
    return _StepRepr.Handle_StepRepr_ConfigurationEffectivity_DownCast(t)

def Handle_StepRepr_ConfigurationEffectivity_IsNull(t: "opencascade::handle< StepRepr_ConfigurationEffectivity > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ConfigurationEffectivity_IsNull(t)

def Handle_StepRepr_ConfigurationItem_Create() -> "opencascade::handle< StepRepr_ConfigurationItem >":
    return _StepRepr.Handle_StepRepr_ConfigurationItem_Create()

def Handle_StepRepr_ConfigurationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ConfigurationItem >":
    return _StepRepr.Handle_StepRepr_ConfigurationItem_DownCast(t)

def Handle_StepRepr_ConfigurationItem_IsNull(t: "opencascade::handle< StepRepr_ConfigurationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ConfigurationItem_IsNull(t)

def Handle_StepRepr_DataEnvironment_Create() -> "opencascade::handle< StepRepr_DataEnvironment >":
    return _StepRepr.Handle_StepRepr_DataEnvironment_Create()

def Handle_StepRepr_DataEnvironment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_DataEnvironment >":
    return _StepRepr.Handle_StepRepr_DataEnvironment_DownCast(t)

def Handle_StepRepr_DataEnvironment_IsNull(t: "opencascade::handle< StepRepr_DataEnvironment > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_DataEnvironment_IsNull(t)

def Handle_StepRepr_FunctionallyDefinedTransformation_Create() -> "opencascade::handle< StepRepr_FunctionallyDefinedTransformation >":
    return _StepRepr.Handle_StepRepr_FunctionallyDefinedTransformation_Create()

def Handle_StepRepr_FunctionallyDefinedTransformation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_FunctionallyDefinedTransformation >":
    return _StepRepr.Handle_StepRepr_FunctionallyDefinedTransformation_DownCast(t)

def Handle_StepRepr_FunctionallyDefinedTransformation_IsNull(t: "opencascade::handle< StepRepr_FunctionallyDefinedTransformation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_FunctionallyDefinedTransformation_IsNull(t)

def Handle_StepRepr_ItemDefinedTransformation_Create() -> "opencascade::handle< StepRepr_ItemDefinedTransformation >":
    return _StepRepr.Handle_StepRepr_ItemDefinedTransformation_Create()

def Handle_StepRepr_ItemDefinedTransformation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ItemDefinedTransformation >":
    return _StepRepr.Handle_StepRepr_ItemDefinedTransformation_DownCast(t)

def Handle_StepRepr_ItemDefinedTransformation_IsNull(t: "opencascade::handle< StepRepr_ItemDefinedTransformation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ItemDefinedTransformation_IsNull(t)

def Handle_StepRepr_MaterialDesignation_Create() -> "opencascade::handle< StepRepr_MaterialDesignation >":
    return _StepRepr.Handle_StepRepr_MaterialDesignation_Create()

def Handle_StepRepr_MaterialDesignation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_MaterialDesignation >":
    return _StepRepr.Handle_StepRepr_MaterialDesignation_DownCast(t)

def Handle_StepRepr_MaterialDesignation_IsNull(t: "opencascade::handle< StepRepr_MaterialDesignation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_MaterialDesignation_IsNull(t)

def Handle_StepRepr_ProductConcept_Create() -> "opencascade::handle< StepRepr_ProductConcept >":
    return _StepRepr.Handle_StepRepr_ProductConcept_Create()

def Handle_StepRepr_ProductConcept_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ProductConcept >":
    return _StepRepr.Handle_StepRepr_ProductConcept_DownCast(t)

def Handle_StepRepr_ProductConcept_IsNull(t: "opencascade::handle< StepRepr_ProductConcept > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ProductConcept_IsNull(t)

def Handle_StepRepr_ProductDefinitionUsage_Create() -> "opencascade::handle< StepRepr_ProductDefinitionUsage >":
    return _StepRepr.Handle_StepRepr_ProductDefinitionUsage_Create()

def Handle_StepRepr_ProductDefinitionUsage_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ProductDefinitionUsage >":
    return _StepRepr.Handle_StepRepr_ProductDefinitionUsage_DownCast(t)

def Handle_StepRepr_ProductDefinitionUsage_IsNull(t: "opencascade::handle< StepRepr_ProductDefinitionUsage > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ProductDefinitionUsage_IsNull(t)

def Handle_StepRepr_PropertyDefinition_Create() -> "opencascade::handle< StepRepr_PropertyDefinition >":
    return _StepRepr.Handle_StepRepr_PropertyDefinition_Create()

def Handle_StepRepr_PropertyDefinition_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_PropertyDefinition >":
    return _StepRepr.Handle_StepRepr_PropertyDefinition_DownCast(t)

def Handle_StepRepr_PropertyDefinition_IsNull(t: "opencascade::handle< StepRepr_PropertyDefinition > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_PropertyDefinition_IsNull(t)

def Handle_StepRepr_PropertyDefinitionRelationship_Create() -> "opencascade::handle< StepRepr_PropertyDefinitionRelationship >":
    return _StepRepr.Handle_StepRepr_PropertyDefinitionRelationship_Create()

def Handle_StepRepr_PropertyDefinitionRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_PropertyDefinitionRelationship >":
    return _StepRepr.Handle_StepRepr_PropertyDefinitionRelationship_DownCast(t)

def Handle_StepRepr_PropertyDefinitionRelationship_IsNull(t: "opencascade::handle< StepRepr_PropertyDefinitionRelationship > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_PropertyDefinitionRelationship_IsNull(t)

def Handle_StepRepr_PropertyDefinitionRepresentation_Create() -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation >":
    return _StepRepr.Handle_StepRepr_PropertyDefinitionRepresentation_Create()

def Handle_StepRepr_PropertyDefinitionRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation >":
    return _StepRepr.Handle_StepRepr_PropertyDefinitionRepresentation_DownCast(t)

def Handle_StepRepr_PropertyDefinitionRepresentation_IsNull(t: "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_PropertyDefinitionRepresentation_IsNull(t)

def Handle_StepRepr_Representation_Create() -> "opencascade::handle< StepRepr_Representation >":
    return _StepRepr.Handle_StepRepr_Representation_Create()

def Handle_StepRepr_Representation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_Representation >":
    return _StepRepr.Handle_StepRepr_Representation_DownCast(t)

def Handle_StepRepr_Representation_IsNull(t: "opencascade::handle< StepRepr_Representation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_Representation_IsNull(t)

def Handle_StepRepr_RepresentationContext_Create() -> "opencascade::handle< StepRepr_RepresentationContext >":
    return _StepRepr.Handle_StepRepr_RepresentationContext_Create()

def Handle_StepRepr_RepresentationContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_RepresentationContext >":
    return _StepRepr.Handle_StepRepr_RepresentationContext_DownCast(t)

def Handle_StepRepr_RepresentationContext_IsNull(t: "opencascade::handle< StepRepr_RepresentationContext > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_RepresentationContext_IsNull(t)

def Handle_StepRepr_RepresentationItem_Create() -> "opencascade::handle< StepRepr_RepresentationItem >":
    return _StepRepr.Handle_StepRepr_RepresentationItem_Create()

def Handle_StepRepr_RepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_RepresentationItem >":
    return _StepRepr.Handle_StepRepr_RepresentationItem_DownCast(t)

def Handle_StepRepr_RepresentationItem_IsNull(t: "opencascade::handle< StepRepr_RepresentationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_RepresentationItem_IsNull(t)

def Handle_StepRepr_RepresentationMap_Create() -> "opencascade::handle< StepRepr_RepresentationMap >":
    return _StepRepr.Handle_StepRepr_RepresentationMap_Create()

def Handle_StepRepr_RepresentationMap_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_RepresentationMap >":
    return _StepRepr.Handle_StepRepr_RepresentationMap_DownCast(t)

def Handle_StepRepr_RepresentationMap_IsNull(t: "opencascade::handle< StepRepr_RepresentationMap > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_RepresentationMap_IsNull(t)

def Handle_StepRepr_RepresentationRelationship_Create() -> "opencascade::handle< StepRepr_RepresentationRelationship >":
    return _StepRepr.Handle_StepRepr_RepresentationRelationship_Create()

def Handle_StepRepr_RepresentationRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_RepresentationRelationship >":
    return _StepRepr.Handle_StepRepr_RepresentationRelationship_DownCast(t)

def Handle_StepRepr_RepresentationRelationship_IsNull(t: "opencascade::handle< StepRepr_RepresentationRelationship > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_RepresentationRelationship_IsNull(t)

def Handle_StepRepr_ShapeAspect_Create() -> "opencascade::handle< StepRepr_ShapeAspect >":
    return _StepRepr.Handle_StepRepr_ShapeAspect_Create()

def Handle_StepRepr_ShapeAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ShapeAspect >":
    return _StepRepr.Handle_StepRepr_ShapeAspect_DownCast(t)

def Handle_StepRepr_ShapeAspect_IsNull(t: "opencascade::handle< StepRepr_ShapeAspect > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ShapeAspect_IsNull(t)

def Handle_StepRepr_ShapeAspectRelationship_Create() -> "opencascade::handle< StepRepr_ShapeAspectRelationship >":
    return _StepRepr.Handle_StepRepr_ShapeAspectRelationship_Create()

def Handle_StepRepr_ShapeAspectRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ShapeAspectRelationship >":
    return _StepRepr.Handle_StepRepr_ShapeAspectRelationship_DownCast(t)

def Handle_StepRepr_ShapeAspectRelationship_IsNull(t: "opencascade::handle< StepRepr_ShapeAspectRelationship > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ShapeAspectRelationship_IsNull(t)

def Handle_StepRepr_SuppliedPartRelationship_Create() -> "opencascade::handle< StepRepr_SuppliedPartRelationship >":
    return _StepRepr.Handle_StepRepr_SuppliedPartRelationship_Create()

def Handle_StepRepr_SuppliedPartRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_SuppliedPartRelationship >":
    return _StepRepr.Handle_StepRepr_SuppliedPartRelationship_DownCast(t)

def Handle_StepRepr_SuppliedPartRelationship_IsNull(t: "opencascade::handle< StepRepr_SuppliedPartRelationship > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_SuppliedPartRelationship_IsNull(t)

def Handle_StepRepr_AssemblyComponentUsage_Create() -> "opencascade::handle< StepRepr_AssemblyComponentUsage >":
    return _StepRepr.Handle_StepRepr_AssemblyComponentUsage_Create()

def Handle_StepRepr_AssemblyComponentUsage_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_AssemblyComponentUsage >":
    return _StepRepr.Handle_StepRepr_AssemblyComponentUsage_DownCast(t)

def Handle_StepRepr_AssemblyComponentUsage_IsNull(t: "opencascade::handle< StepRepr_AssemblyComponentUsage > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_AssemblyComponentUsage_IsNull(t)

def Handle_StepRepr_CharacterizedRepresentation_Create() -> "opencascade::handle< StepRepr_CharacterizedRepresentation >":
    return _StepRepr.Handle_StepRepr_CharacterizedRepresentation_Create()

def Handle_StepRepr_CharacterizedRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_CharacterizedRepresentation >":
    return _StepRepr.Handle_StepRepr_CharacterizedRepresentation_DownCast(t)

def Handle_StepRepr_CharacterizedRepresentation_IsNull(t: "opencascade::handle< StepRepr_CharacterizedRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_CharacterizedRepresentation_IsNull(t)

def Handle_StepRepr_CompShAspAndDatumFeatAndShAsp_Create() -> "opencascade::handle< StepRepr_CompShAspAndDatumFeatAndShAsp >":
    return _StepRepr.Handle_StepRepr_CompShAspAndDatumFeatAndShAsp_Create()

def Handle_StepRepr_CompShAspAndDatumFeatAndShAsp_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_CompShAspAndDatumFeatAndShAsp >":
    return _StepRepr.Handle_StepRepr_CompShAspAndDatumFeatAndShAsp_DownCast(t)

def Handle_StepRepr_CompShAspAndDatumFeatAndShAsp_IsNull(t: "opencascade::handle< StepRepr_CompShAspAndDatumFeatAndShAsp > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_CompShAspAndDatumFeatAndShAsp_IsNull(t)

def Handle_StepRepr_CompositeShapeAspect_Create() -> "opencascade::handle< StepRepr_CompositeShapeAspect >":
    return _StepRepr.Handle_StepRepr_CompositeShapeAspect_Create()

def Handle_StepRepr_CompositeShapeAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_CompositeShapeAspect >":
    return _StepRepr.Handle_StepRepr_CompositeShapeAspect_DownCast(t)

def Handle_StepRepr_CompositeShapeAspect_IsNull(t: "opencascade::handle< StepRepr_CompositeShapeAspect > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_CompositeShapeAspect_IsNull(t)

def Handle_StepRepr_CompoundRepresentationItem_Create() -> "opencascade::handle< StepRepr_CompoundRepresentationItem >":
    return _StepRepr.Handle_StepRepr_CompoundRepresentationItem_Create()

def Handle_StepRepr_CompoundRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_CompoundRepresentationItem >":
    return _StepRepr.Handle_StepRepr_CompoundRepresentationItem_DownCast(t)

def Handle_StepRepr_CompoundRepresentationItem_IsNull(t: "opencascade::handle< StepRepr_CompoundRepresentationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_CompoundRepresentationItem_IsNull(t)

def Handle_StepRepr_ConstructiveGeometryRepresentation_Create() -> "opencascade::handle< StepRepr_ConstructiveGeometryRepresentation >":
    return _StepRepr.Handle_StepRepr_ConstructiveGeometryRepresentation_Create()

def Handle_StepRepr_ConstructiveGeometryRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ConstructiveGeometryRepresentation >":
    return _StepRepr.Handle_StepRepr_ConstructiveGeometryRepresentation_DownCast(t)

def Handle_StepRepr_ConstructiveGeometryRepresentation_IsNull(t: "opencascade::handle< StepRepr_ConstructiveGeometryRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ConstructiveGeometryRepresentation_IsNull(t)

def Handle_StepRepr_ConstructiveGeometryRepresentationRelationship_Create() -> "opencascade::handle< StepRepr_ConstructiveGeometryRepresentationRelationship >":
    return _StepRepr.Handle_StepRepr_ConstructiveGeometryRepresentationRelationship_Create()

def Handle_StepRepr_ConstructiveGeometryRepresentationRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ConstructiveGeometryRepresentationRelationship >":
    return _StepRepr.Handle_StepRepr_ConstructiveGeometryRepresentationRelationship_DownCast(t)

def Handle_StepRepr_ConstructiveGeometryRepresentationRelationship_IsNull(t: "opencascade::handle< StepRepr_ConstructiveGeometryRepresentationRelationship > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ConstructiveGeometryRepresentationRelationship_IsNull(t)

def Handle_StepRepr_DefinitionalRepresentation_Create() -> "opencascade::handle< StepRepr_DefinitionalRepresentation >":
    return _StepRepr.Handle_StepRepr_DefinitionalRepresentation_Create()

def Handle_StepRepr_DefinitionalRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_DefinitionalRepresentation >":
    return _StepRepr.Handle_StepRepr_DefinitionalRepresentation_DownCast(t)

def Handle_StepRepr_DefinitionalRepresentation_IsNull(t: "opencascade::handle< StepRepr_DefinitionalRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_DefinitionalRepresentation_IsNull(t)

def Handle_StepRepr_DerivedShapeAspect_Create() -> "opencascade::handle< StepRepr_DerivedShapeAspect >":
    return _StepRepr.Handle_StepRepr_DerivedShapeAspect_Create()

def Handle_StepRepr_DerivedShapeAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_DerivedShapeAspect >":
    return _StepRepr.Handle_StepRepr_DerivedShapeAspect_DownCast(t)

def Handle_StepRepr_DerivedShapeAspect_IsNull(t: "opencascade::handle< StepRepr_DerivedShapeAspect > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_DerivedShapeAspect_IsNull(t)

def Handle_StepRepr_DescriptiveRepresentationItem_Create() -> "opencascade::handle< StepRepr_DescriptiveRepresentationItem >":
    return _StepRepr.Handle_StepRepr_DescriptiveRepresentationItem_Create()

def Handle_StepRepr_DescriptiveRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_DescriptiveRepresentationItem >":
    return _StepRepr.Handle_StepRepr_DescriptiveRepresentationItem_DownCast(t)

def Handle_StepRepr_DescriptiveRepresentationItem_IsNull(t: "opencascade::handle< StepRepr_DescriptiveRepresentationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_DescriptiveRepresentationItem_IsNull(t)

def Handle_StepRepr_ExternallyDefinedRepresentation_Create() -> "opencascade::handle< StepRepr_ExternallyDefinedRepresentation >":
    return _StepRepr.Handle_StepRepr_ExternallyDefinedRepresentation_Create()

def Handle_StepRepr_ExternallyDefinedRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ExternallyDefinedRepresentation >":
    return _StepRepr.Handle_StepRepr_ExternallyDefinedRepresentation_DownCast(t)

def Handle_StepRepr_ExternallyDefinedRepresentation_IsNull(t: "opencascade::handle< StepRepr_ExternallyDefinedRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ExternallyDefinedRepresentation_IsNull(t)

def Handle_StepRepr_FeatureForDatumTargetRelationship_Create() -> "opencascade::handle< StepRepr_FeatureForDatumTargetRelationship >":
    return _StepRepr.Handle_StepRepr_FeatureForDatumTargetRelationship_Create()

def Handle_StepRepr_FeatureForDatumTargetRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_FeatureForDatumTargetRelationship >":
    return _StepRepr.Handle_StepRepr_FeatureForDatumTargetRelationship_DownCast(t)

def Handle_StepRepr_FeatureForDatumTargetRelationship_IsNull(t: "opencascade::handle< StepRepr_FeatureForDatumTargetRelationship > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_FeatureForDatumTargetRelationship_IsNull(t)

def Handle_StepRepr_GlobalUncertaintyAssignedContext_Create() -> "opencascade::handle< StepRepr_GlobalUncertaintyAssignedContext >":
    return _StepRepr.Handle_StepRepr_GlobalUncertaintyAssignedContext_Create()

def Handle_StepRepr_GlobalUncertaintyAssignedContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_GlobalUncertaintyAssignedContext >":
    return _StepRepr.Handle_StepRepr_GlobalUncertaintyAssignedContext_DownCast(t)

def Handle_StepRepr_GlobalUncertaintyAssignedContext_IsNull(t: "opencascade::handle< StepRepr_GlobalUncertaintyAssignedContext > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_GlobalUncertaintyAssignedContext_IsNull(t)

def Handle_StepRepr_GlobalUnitAssignedContext_Create() -> "opencascade::handle< StepRepr_GlobalUnitAssignedContext >":
    return _StepRepr.Handle_StepRepr_GlobalUnitAssignedContext_Create()

def Handle_StepRepr_GlobalUnitAssignedContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_GlobalUnitAssignedContext >":
    return _StepRepr.Handle_StepRepr_GlobalUnitAssignedContext_DownCast(t)

def Handle_StepRepr_GlobalUnitAssignedContext_IsNull(t: "opencascade::handle< StepRepr_GlobalUnitAssignedContext > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_GlobalUnitAssignedContext_IsNull(t)

def Handle_StepRepr_IntegerRepresentationItem_Create() -> "opencascade::handle< StepRepr_IntegerRepresentationItem >":
    return _StepRepr.Handle_StepRepr_IntegerRepresentationItem_Create()

def Handle_StepRepr_IntegerRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_IntegerRepresentationItem >":
    return _StepRepr.Handle_StepRepr_IntegerRepresentationItem_DownCast(t)

def Handle_StepRepr_IntegerRepresentationItem_IsNull(t: "opencascade::handle< StepRepr_IntegerRepresentationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_IntegerRepresentationItem_IsNull(t)

def Handle_StepRepr_MakeFromUsageOption_Create() -> "opencascade::handle< StepRepr_MakeFromUsageOption >":
    return _StepRepr.Handle_StepRepr_MakeFromUsageOption_Create()

def Handle_StepRepr_MakeFromUsageOption_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_MakeFromUsageOption >":
    return _StepRepr.Handle_StepRepr_MakeFromUsageOption_DownCast(t)

def Handle_StepRepr_MakeFromUsageOption_IsNull(t: "opencascade::handle< StepRepr_MakeFromUsageOption > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_MakeFromUsageOption_IsNull(t)

def Handle_StepRepr_MappedItem_Create() -> "opencascade::handle< StepRepr_MappedItem >":
    return _StepRepr.Handle_StepRepr_MappedItem_Create()

def Handle_StepRepr_MappedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_MappedItem >":
    return _StepRepr.Handle_StepRepr_MappedItem_DownCast(t)

def Handle_StepRepr_MappedItem_IsNull(t: "opencascade::handle< StepRepr_MappedItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_MappedItem_IsNull(t)

def Handle_StepRepr_MaterialProperty_Create() -> "opencascade::handle< StepRepr_MaterialProperty >":
    return _StepRepr.Handle_StepRepr_MaterialProperty_Create()

def Handle_StepRepr_MaterialProperty_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_MaterialProperty >":
    return _StepRepr.Handle_StepRepr_MaterialProperty_DownCast(t)

def Handle_StepRepr_MaterialProperty_IsNull(t: "opencascade::handle< StepRepr_MaterialProperty > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_MaterialProperty_IsNull(t)

def Handle_StepRepr_MaterialPropertyRepresentation_Create() -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation >":
    return _StepRepr.Handle_StepRepr_MaterialPropertyRepresentation_Create()

def Handle_StepRepr_MaterialPropertyRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation >":
    return _StepRepr.Handle_StepRepr_MaterialPropertyRepresentation_DownCast(t)

def Handle_StepRepr_MaterialPropertyRepresentation_IsNull(t: "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_MaterialPropertyRepresentation_IsNull(t)

def Handle_StepRepr_MeasureRepresentationItem_Create() -> "opencascade::handle< StepRepr_MeasureRepresentationItem >":
    return _StepRepr.Handle_StepRepr_MeasureRepresentationItem_Create()

def Handle_StepRepr_MeasureRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_MeasureRepresentationItem >":
    return _StepRepr.Handle_StepRepr_MeasureRepresentationItem_DownCast(t)

def Handle_StepRepr_MeasureRepresentationItem_IsNull(t: "opencascade::handle< StepRepr_MeasureRepresentationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_MeasureRepresentationItem_IsNull(t)

def Handle_StepRepr_ParametricRepresentationContext_Create() -> "opencascade::handle< StepRepr_ParametricRepresentationContext >":
    return _StepRepr.Handle_StepRepr_ParametricRepresentationContext_Create()

def Handle_StepRepr_ParametricRepresentationContext_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ParametricRepresentationContext >":
    return _StepRepr.Handle_StepRepr_ParametricRepresentationContext_DownCast(t)

def Handle_StepRepr_ParametricRepresentationContext_IsNull(t: "opencascade::handle< StepRepr_ParametricRepresentationContext > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ParametricRepresentationContext_IsNull(t)

def Handle_StepRepr_ProductDefinitionShape_Create() -> "opencascade::handle< StepRepr_ProductDefinitionShape >":
    return _StepRepr.Handle_StepRepr_ProductDefinitionShape_Create()

def Handle_StepRepr_ProductDefinitionShape_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ProductDefinitionShape >":
    return _StepRepr.Handle_StepRepr_ProductDefinitionShape_DownCast(t)

def Handle_StepRepr_ProductDefinitionShape_IsNull(t: "opencascade::handle< StepRepr_ProductDefinitionShape > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ProductDefinitionShape_IsNull(t)

def Handle_StepRepr_ReprItemAndMeasureWithUnit_Create() -> "opencascade::handle< StepRepr_ReprItemAndMeasureWithUnit >":
    return _StepRepr.Handle_StepRepr_ReprItemAndMeasureWithUnit_Create()

def Handle_StepRepr_ReprItemAndMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ReprItemAndMeasureWithUnit >":
    return _StepRepr.Handle_StepRepr_ReprItemAndMeasureWithUnit_DownCast(t)

def Handle_StepRepr_ReprItemAndMeasureWithUnit_IsNull(t: "opencascade::handle< StepRepr_ReprItemAndMeasureWithUnit > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ReprItemAndMeasureWithUnit_IsNull(t)

def Handle_StepRepr_ShapeAspectDerivingRelationship_Create() -> "opencascade::handle< StepRepr_ShapeAspectDerivingRelationship >":
    return _StepRepr.Handle_StepRepr_ShapeAspectDerivingRelationship_Create()

def Handle_StepRepr_ShapeAspectDerivingRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ShapeAspectDerivingRelationship >":
    return _StepRepr.Handle_StepRepr_ShapeAspectDerivingRelationship_DownCast(t)

def Handle_StepRepr_ShapeAspectDerivingRelationship_IsNull(t: "opencascade::handle< StepRepr_ShapeAspectDerivingRelationship > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ShapeAspectDerivingRelationship_IsNull(t)

def Handle_StepRepr_ShapeAspectTransition_Create() -> "opencascade::handle< StepRepr_ShapeAspectTransition >":
    return _StepRepr.Handle_StepRepr_ShapeAspectTransition_Create()

def Handle_StepRepr_ShapeAspectTransition_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ShapeAspectTransition >":
    return _StepRepr.Handle_StepRepr_ShapeAspectTransition_DownCast(t)

def Handle_StepRepr_ShapeAspectTransition_IsNull(t: "opencascade::handle< StepRepr_ShapeAspectTransition > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ShapeAspectTransition_IsNull(t)

def Handle_StepRepr_ShapeRepresentationRelationship_Create() -> "opencascade::handle< StepRepr_ShapeRepresentationRelationship >":
    return _StepRepr.Handle_StepRepr_ShapeRepresentationRelationship_Create()

def Handle_StepRepr_ShapeRepresentationRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ShapeRepresentationRelationship >":
    return _StepRepr.Handle_StepRepr_ShapeRepresentationRelationship_DownCast(t)

def Handle_StepRepr_ShapeRepresentationRelationship_IsNull(t: "opencascade::handle< StepRepr_ShapeRepresentationRelationship > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ShapeRepresentationRelationship_IsNull(t)

def Handle_StepRepr_StructuralResponseProperty_Create() -> "opencascade::handle< StepRepr_StructuralResponseProperty >":
    return _StepRepr.Handle_StepRepr_StructuralResponseProperty_Create()

def Handle_StepRepr_StructuralResponseProperty_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_StructuralResponseProperty >":
    return _StepRepr.Handle_StepRepr_StructuralResponseProperty_DownCast(t)

def Handle_StepRepr_StructuralResponseProperty_IsNull(t: "opencascade::handle< StepRepr_StructuralResponseProperty > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_StructuralResponseProperty_IsNull(t)

def Handle_StepRepr_StructuralResponsePropertyDefinitionRepresentation_Create() -> "opencascade::handle< StepRepr_StructuralResponsePropertyDefinitionRepresentation >":
    return _StepRepr.Handle_StepRepr_StructuralResponsePropertyDefinitionRepresentation_Create()

def Handle_StepRepr_StructuralResponsePropertyDefinitionRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_StructuralResponsePropertyDefinitionRepresentation >":
    return _StepRepr.Handle_StepRepr_StructuralResponsePropertyDefinitionRepresentation_DownCast(t)

def Handle_StepRepr_StructuralResponsePropertyDefinitionRepresentation_IsNull(t: "opencascade::handle< StepRepr_StructuralResponsePropertyDefinitionRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_StructuralResponsePropertyDefinitionRepresentation_IsNull(t)

def Handle_StepRepr_ValueRepresentationItem_Create() -> "opencascade::handle< StepRepr_ValueRepresentationItem >":
    return _StepRepr.Handle_StepRepr_ValueRepresentationItem_Create()

def Handle_StepRepr_ValueRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ValueRepresentationItem >":
    return _StepRepr.Handle_StepRepr_ValueRepresentationItem_DownCast(t)

def Handle_StepRepr_ValueRepresentationItem_IsNull(t: "opencascade::handle< StepRepr_ValueRepresentationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ValueRepresentationItem_IsNull(t)

def Handle_StepRepr_Apex_Create() -> "opencascade::handle< StepRepr_Apex >":
    return _StepRepr.Handle_StepRepr_Apex_Create()

def Handle_StepRepr_Apex_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_Apex >":
    return _StepRepr.Handle_StepRepr_Apex_DownCast(t)

def Handle_StepRepr_Apex_IsNull(t: "opencascade::handle< StepRepr_Apex > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_Apex_IsNull(t)

def Handle_StepRepr_CentreOfSymmetry_Create() -> "opencascade::handle< StepRepr_CentreOfSymmetry >":
    return _StepRepr.Handle_StepRepr_CentreOfSymmetry_Create()

def Handle_StepRepr_CentreOfSymmetry_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_CentreOfSymmetry >":
    return _StepRepr.Handle_StepRepr_CentreOfSymmetry_DownCast(t)

def Handle_StepRepr_CentreOfSymmetry_IsNull(t: "opencascade::handle< StepRepr_CentreOfSymmetry > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_CentreOfSymmetry_IsNull(t)

def Handle_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_Create() -> "opencascade::handle< StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp >":
    return _StepRepr.Handle_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_Create()

def Handle_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp >":
    return _StepRepr.Handle_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_DownCast(t)

def Handle_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_IsNull(t: "opencascade::handle< StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_IsNull(t)

def Handle_StepRepr_CompositeGroupShapeAspect_Create() -> "opencascade::handle< StepRepr_CompositeGroupShapeAspect >":
    return _StepRepr.Handle_StepRepr_CompositeGroupShapeAspect_Create()

def Handle_StepRepr_CompositeGroupShapeAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_CompositeGroupShapeAspect >":
    return _StepRepr.Handle_StepRepr_CompositeGroupShapeAspect_DownCast(t)

def Handle_StepRepr_CompositeGroupShapeAspect_IsNull(t: "opencascade::handle< StepRepr_CompositeGroupShapeAspect > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_CompositeGroupShapeAspect_IsNull(t)

def Handle_StepRepr_ContinuosShapeAspect_Create() -> "opencascade::handle< StepRepr_ContinuosShapeAspect >":
    return _StepRepr.Handle_StepRepr_ContinuosShapeAspect_Create()

def Handle_StepRepr_ContinuosShapeAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ContinuosShapeAspect >":
    return _StepRepr.Handle_StepRepr_ContinuosShapeAspect_DownCast(t)

def Handle_StepRepr_ContinuosShapeAspect_IsNull(t: "opencascade::handle< StepRepr_ContinuosShapeAspect > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ContinuosShapeAspect_IsNull(t)

def Handle_StepRepr_Extension_Create() -> "opencascade::handle< StepRepr_Extension >":
    return _StepRepr.Handle_StepRepr_Extension_Create()

def Handle_StepRepr_Extension_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_Extension >":
    return _StepRepr.Handle_StepRepr_Extension_DownCast(t)

def Handle_StepRepr_Extension_IsNull(t: "opencascade::handle< StepRepr_Extension > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_Extension_IsNull(t)

def Handle_StepRepr_GeometricAlignment_Create() -> "opencascade::handle< StepRepr_GeometricAlignment >":
    return _StepRepr.Handle_StepRepr_GeometricAlignment_Create()

def Handle_StepRepr_GeometricAlignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_GeometricAlignment >":
    return _StepRepr.Handle_StepRepr_GeometricAlignment_DownCast(t)

def Handle_StepRepr_GeometricAlignment_IsNull(t: "opencascade::handle< StepRepr_GeometricAlignment > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_GeometricAlignment_IsNull(t)

def Handle_StepRepr_NextAssemblyUsageOccurrence_Create() -> "opencascade::handle< StepRepr_NextAssemblyUsageOccurrence >":
    return _StepRepr.Handle_StepRepr_NextAssemblyUsageOccurrence_Create()

def Handle_StepRepr_NextAssemblyUsageOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_NextAssemblyUsageOccurrence >":
    return _StepRepr.Handle_StepRepr_NextAssemblyUsageOccurrence_DownCast(t)

def Handle_StepRepr_NextAssemblyUsageOccurrence_IsNull(t: "opencascade::handle< StepRepr_NextAssemblyUsageOccurrence > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_NextAssemblyUsageOccurrence_IsNull(t)

def Handle_StepRepr_ParallelOffset_Create() -> "opencascade::handle< StepRepr_ParallelOffset >":
    return _StepRepr.Handle_StepRepr_ParallelOffset_Create()

def Handle_StepRepr_ParallelOffset_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ParallelOffset >":
    return _StepRepr.Handle_StepRepr_ParallelOffset_DownCast(t)

def Handle_StepRepr_ParallelOffset_IsNull(t: "opencascade::handle< StepRepr_ParallelOffset > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ParallelOffset_IsNull(t)

def Handle_StepRepr_PerpendicularTo_Create() -> "opencascade::handle< StepRepr_PerpendicularTo >":
    return _StepRepr.Handle_StepRepr_PerpendicularTo_Create()

def Handle_StepRepr_PerpendicularTo_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_PerpendicularTo >":
    return _StepRepr.Handle_StepRepr_PerpendicularTo_DownCast(t)

def Handle_StepRepr_PerpendicularTo_IsNull(t: "opencascade::handle< StepRepr_PerpendicularTo > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_PerpendicularTo_IsNull(t)

def Handle_StepRepr_PromissoryUsageOccurrence_Create() -> "opencascade::handle< StepRepr_PromissoryUsageOccurrence >":
    return _StepRepr.Handle_StepRepr_PromissoryUsageOccurrence_Create()

def Handle_StepRepr_PromissoryUsageOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_PromissoryUsageOccurrence >":
    return _StepRepr.Handle_StepRepr_PromissoryUsageOccurrence_DownCast(t)

def Handle_StepRepr_PromissoryUsageOccurrence_IsNull(t: "opencascade::handle< StepRepr_PromissoryUsageOccurrence > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_PromissoryUsageOccurrence_IsNull(t)

def Handle_StepRepr_QuantifiedAssemblyComponentUsage_Create() -> "opencascade::handle< StepRepr_QuantifiedAssemblyComponentUsage >":
    return _StepRepr.Handle_StepRepr_QuantifiedAssemblyComponentUsage_Create()

def Handle_StepRepr_QuantifiedAssemblyComponentUsage_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_QuantifiedAssemblyComponentUsage >":
    return _StepRepr.Handle_StepRepr_QuantifiedAssemblyComponentUsage_DownCast(t)

def Handle_StepRepr_QuantifiedAssemblyComponentUsage_IsNull(t: "opencascade::handle< StepRepr_QuantifiedAssemblyComponentUsage > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_QuantifiedAssemblyComponentUsage_IsNull(t)

def Handle_StepRepr_ReprItemAndLengthMeasureWithUnit_Create() -> "opencascade::handle< StepRepr_ReprItemAndLengthMeasureWithUnit >":
    return _StepRepr.Handle_StepRepr_ReprItemAndLengthMeasureWithUnit_Create()

def Handle_StepRepr_ReprItemAndLengthMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ReprItemAndLengthMeasureWithUnit >":
    return _StepRepr.Handle_StepRepr_ReprItemAndLengthMeasureWithUnit_DownCast(t)

def Handle_StepRepr_ReprItemAndLengthMeasureWithUnit_IsNull(t: "opencascade::handle< StepRepr_ReprItemAndLengthMeasureWithUnit > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ReprItemAndLengthMeasureWithUnit_IsNull(t)

def Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_Create() -> "opencascade::handle< StepRepr_ReprItemAndPlaneAngleMeasureWithUnit >":
    return _StepRepr.Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_Create()

def Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ReprItemAndPlaneAngleMeasureWithUnit >":
    return _StepRepr.Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_DownCast(t)

def Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_IsNull(t: "opencascade::handle< StepRepr_ReprItemAndPlaneAngleMeasureWithUnit > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_IsNull(t)

def Handle_StepRepr_RepresentationRelationshipWithTransformation_Create() -> "opencascade::handle< StepRepr_RepresentationRelationshipWithTransformation >":
    return _StepRepr.Handle_StepRepr_RepresentationRelationshipWithTransformation_Create()

def Handle_StepRepr_RepresentationRelationshipWithTransformation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_RepresentationRelationshipWithTransformation >":
    return _StepRepr.Handle_StepRepr_RepresentationRelationshipWithTransformation_DownCast(t)

def Handle_StepRepr_RepresentationRelationshipWithTransformation_IsNull(t: "opencascade::handle< StepRepr_RepresentationRelationshipWithTransformation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_RepresentationRelationshipWithTransformation_IsNull(t)

def Handle_StepRepr_SpecifiedHigherUsageOccurrence_Create() -> "opencascade::handle< StepRepr_SpecifiedHigherUsageOccurrence >":
    return _StepRepr.Handle_StepRepr_SpecifiedHigherUsageOccurrence_Create()

def Handle_StepRepr_SpecifiedHigherUsageOccurrence_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_SpecifiedHigherUsageOccurrence >":
    return _StepRepr.Handle_StepRepr_SpecifiedHigherUsageOccurrence_DownCast(t)

def Handle_StepRepr_SpecifiedHigherUsageOccurrence_IsNull(t: "opencascade::handle< StepRepr_SpecifiedHigherUsageOccurrence > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_SpecifiedHigherUsageOccurrence_IsNull(t)

def Handle_StepRepr_Tangent_Create() -> "opencascade::handle< StepRepr_Tangent >":
    return _StepRepr.Handle_StepRepr_Tangent_Create()

def Handle_StepRepr_Tangent_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_Tangent >":
    return _StepRepr.Handle_StepRepr_Tangent_DownCast(t)

def Handle_StepRepr_Tangent_IsNull(t: "opencascade::handle< StepRepr_Tangent > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_Tangent_IsNull(t)

def Handle_StepRepr_ValueRange_Create() -> "opencascade::handle< StepRepr_ValueRange >":
    return _StepRepr.Handle_StepRepr_ValueRange_Create()

def Handle_StepRepr_ValueRange_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ValueRange >":
    return _StepRepr.Handle_StepRepr_ValueRange_DownCast(t)

def Handle_StepRepr_ValueRange_IsNull(t: "opencascade::handle< StepRepr_ValueRange > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ValueRange_IsNull(t)

def Handle_StepRepr_AllAroundShapeAspect_Create() -> "opencascade::handle< StepRepr_AllAroundShapeAspect >":
    return _StepRepr.Handle_StepRepr_AllAroundShapeAspect_Create()

def Handle_StepRepr_AllAroundShapeAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_AllAroundShapeAspect >":
    return _StepRepr.Handle_StepRepr_AllAroundShapeAspect_DownCast(t)

def Handle_StepRepr_AllAroundShapeAspect_IsNull(t: "opencascade::handle< StepRepr_AllAroundShapeAspect > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_AllAroundShapeAspect_IsNull(t)

def Handle_StepRepr_BetweenShapeAspect_Create() -> "opencascade::handle< StepRepr_BetweenShapeAspect >":
    return _StepRepr.Handle_StepRepr_BetweenShapeAspect_Create()

def Handle_StepRepr_BetweenShapeAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_BetweenShapeAspect >":
    return _StepRepr.Handle_StepRepr_BetweenShapeAspect_DownCast(t)

def Handle_StepRepr_BetweenShapeAspect_IsNull(t: "opencascade::handle< StepRepr_BetweenShapeAspect > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_BetweenShapeAspect_IsNull(t)

def Handle_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_Create() -> "opencascade::handle< StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI >":
    return _StepRepr.Handle_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_Create()

def Handle_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI >":
    return _StepRepr.Handle_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_DownCast(t)

def Handle_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_IsNull(t: "opencascade::handle< StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_IsNull(t)

def Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_Create() -> "opencascade::handle< StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI >":
    return _StepRepr.Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_Create()

def Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI >":
    return _StepRepr.Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_DownCast(t)

def Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_IsNull(t: "opencascade::handle< StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_IsNull(t)

def Handle_StepRepr_ShapeRepresentationRelationshipWithTransformation_Create() -> "opencascade::handle< StepRepr_ShapeRepresentationRelationshipWithTransformation >":
    return _StepRepr.Handle_StepRepr_ShapeRepresentationRelationshipWithTransformation_Create()

def Handle_StepRepr_ShapeRepresentationRelationshipWithTransformation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_ShapeRepresentationRelationshipWithTransformation >":
    return _StepRepr.Handle_StepRepr_ShapeRepresentationRelationshipWithTransformation_DownCast(t)

def Handle_StepRepr_ShapeRepresentationRelationshipWithTransformation_IsNull(t: "opencascade::handle< StepRepr_ShapeRepresentationRelationshipWithTransformation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_ShapeRepresentationRelationshipWithTransformation_IsNull(t)

def Handle_StepRepr_HArray1OfMaterialPropertyRepresentation_Create() -> "opencascade::handle< StepRepr_HArray1OfMaterialPropertyRepresentation >":
    return _StepRepr.Handle_StepRepr_HArray1OfMaterialPropertyRepresentation_Create()

def Handle_StepRepr_HArray1OfMaterialPropertyRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_HArray1OfMaterialPropertyRepresentation >":
    return _StepRepr.Handle_StepRepr_HArray1OfMaterialPropertyRepresentation_DownCast(t)

def Handle_StepRepr_HArray1OfMaterialPropertyRepresentation_IsNull(t: "opencascade::handle< StepRepr_HArray1OfMaterialPropertyRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_HArray1OfMaterialPropertyRepresentation_IsNull(t)

def Handle_StepRepr_HArray1OfRepresentationItem_Create() -> "opencascade::handle< StepRepr_HArray1OfRepresentationItem >":
    return _StepRepr.Handle_StepRepr_HArray1OfRepresentationItem_Create()

def Handle_StepRepr_HArray1OfRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_HArray1OfRepresentationItem >":
    return _StepRepr.Handle_StepRepr_HArray1OfRepresentationItem_DownCast(t)

def Handle_StepRepr_HArray1OfRepresentationItem_IsNull(t: "opencascade::handle< StepRepr_HArray1OfRepresentationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_HArray1OfRepresentationItem_IsNull(t)

def Handle_StepRepr_HArray1OfPropertyDefinitionRepresentation_Create() -> "opencascade::handle< StepRepr_HArray1OfPropertyDefinitionRepresentation >":
    return _StepRepr.Handle_StepRepr_HArray1OfPropertyDefinitionRepresentation_Create()

def Handle_StepRepr_HArray1OfPropertyDefinitionRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_HArray1OfPropertyDefinitionRepresentation >":
    return _StepRepr.Handle_StepRepr_HArray1OfPropertyDefinitionRepresentation_DownCast(t)

def Handle_StepRepr_HArray1OfPropertyDefinitionRepresentation_IsNull(t: "opencascade::handle< StepRepr_HArray1OfPropertyDefinitionRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_HArray1OfPropertyDefinitionRepresentation_IsNull(t)

def Handle_StepRepr_HArray1OfShapeAspect_Create() -> "opencascade::handle< StepRepr_HArray1OfShapeAspect >":
    return _StepRepr.Handle_StepRepr_HArray1OfShapeAspect_Create()

def Handle_StepRepr_HArray1OfShapeAspect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_HArray1OfShapeAspect >":
    return _StepRepr.Handle_StepRepr_HArray1OfShapeAspect_DownCast(t)

def Handle_StepRepr_HArray1OfShapeAspect_IsNull(t: "opencascade::handle< StepRepr_HArray1OfShapeAspect > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_HArray1OfShapeAspect_IsNull(t)

def Handle_StepRepr_HSequenceOfRepresentationItem_Create() -> "opencascade::handle< StepRepr_HSequenceOfRepresentationItem >":
    return _StepRepr.Handle_StepRepr_HSequenceOfRepresentationItem_Create()

def Handle_StepRepr_HSequenceOfRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_HSequenceOfRepresentationItem >":
    return _StepRepr.Handle_StepRepr_HSequenceOfRepresentationItem_DownCast(t)

def Handle_StepRepr_HSequenceOfRepresentationItem_IsNull(t: "opencascade::handle< StepRepr_HSequenceOfRepresentationItem > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_HSequenceOfRepresentationItem_IsNull(t)

def Handle_StepRepr_HSequenceOfMaterialPropertyRepresentation_Create() -> "opencascade::handle< StepRepr_HSequenceOfMaterialPropertyRepresentation >":
    return _StepRepr.Handle_StepRepr_HSequenceOfMaterialPropertyRepresentation_Create()

def Handle_StepRepr_HSequenceOfMaterialPropertyRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepRepr_HSequenceOfMaterialPropertyRepresentation >":
    return _StepRepr.Handle_StepRepr_HSequenceOfMaterialPropertyRepresentation_DownCast(t)

def Handle_StepRepr_HSequenceOfMaterialPropertyRepresentation_IsNull(t: "opencascade::handle< StepRepr_HSequenceOfMaterialPropertyRepresentation > const &") -> "bool":
    return _StepRepr.Handle_StepRepr_HSequenceOfMaterialPropertyRepresentation_IsNull(t)
class StepRepr_Array1OfMaterialPropertyRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepRepr_MaterialPropertyRepresentation > >::iterator":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepRepr_MaterialPropertyRepresentation > >::iterator":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepRepr_MaterialPropertyRepresentation > >::const_iterator":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepRepr_MaterialPropertyRepresentation > >::const_iterator":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_cend(self)

    def __init__(self, *args):
        _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_swiginit(self, _StepRepr.new_StepRepr_Array1OfMaterialPropertyRepresentation(*args))

    def Init(self, theValue: "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &") -> "void":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_IsAllocated(self)

    def Assign(self, theOther: "StepRepr_Array1OfMaterialPropertyRepresentation") -> "NCollection_Array1< opencascade::handle< StepRepr_MaterialPropertyRepresentation > > &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Assign(self, theOther)

    def Move(self, theOther: "StepRepr_Array1OfMaterialPropertyRepresentation") -> "NCollection_Array1< opencascade::handle< StepRepr_MaterialPropertyRepresentation > > &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepRepr_MaterialPropertyRepresentation > > &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Set(self, *args)

    def First(self) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > &":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &") -> "void":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepRepr.delete_StepRepr_Array1OfMaterialPropertyRepresentation

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepRepr_Array1OfMaterialPropertyRepresentation in _StepRepr:
_StepRepr.StepRepr_Array1OfMaterialPropertyRepresentation_swigregister(StepRepr_Array1OfMaterialPropertyRepresentation)

class StepRepr_Array1OfPropertyDefinitionRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepRepr_PropertyDefinitionRepresentation > >::iterator":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepRepr_PropertyDefinitionRepresentation > >::iterator":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepRepr_PropertyDefinitionRepresentation > >::const_iterator":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepRepr_PropertyDefinitionRepresentation > >::const_iterator":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_cend(self)

    def __init__(self, *args):
        _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_swiginit(self, _StepRepr.new_StepRepr_Array1OfPropertyDefinitionRepresentation(*args))

    def Init(self, theValue: "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > const &") -> "void":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_IsAllocated(self)

    def Assign(self, theOther: "StepRepr_Array1OfPropertyDefinitionRepresentation") -> "NCollection_Array1< opencascade::handle< StepRepr_PropertyDefinitionRepresentation > > &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Assign(self, theOther)

    def Move(self, theOther: "StepRepr_Array1OfPropertyDefinitionRepresentation") -> "NCollection_Array1< opencascade::handle< StepRepr_PropertyDefinitionRepresentation > > &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepRepr_PropertyDefinitionRepresentation > > &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Set(self, *args)

    def First(self) -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > const &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > const &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > const &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > &":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepRepr_PropertyDefinitionRepresentation > const &") -> "void":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepRepr.delete_StepRepr_Array1OfPropertyDefinitionRepresentation

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepRepr_Array1OfPropertyDefinitionRepresentation in _StepRepr:
_StepRepr.StepRepr_Array1OfPropertyDefinitionRepresentation_swigregister(StepRepr_Array1OfPropertyDefinitionRepresentation)

class StepRepr_Array1OfRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepRepr_RepresentationItem > >::iterator":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepRepr_RepresentationItem > >::iterator":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepRepr_RepresentationItem > >::const_iterator":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepRepr_RepresentationItem > >::const_iterator":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_cend(self)

    def __init__(self, *args):
        _StepRepr.StepRepr_Array1OfRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_Array1OfRepresentationItem(*args))

    def Init(self, theValue: "opencascade::handle< StepRepr_RepresentationItem > const &") -> "void":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_IsAllocated(self)

    def Assign(self, theOther: "StepRepr_Array1OfRepresentationItem") -> "NCollection_Array1< opencascade::handle< StepRepr_RepresentationItem > > &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Assign(self, theOther)

    def Move(self, theOther: "StepRepr_Array1OfRepresentationItem") -> "NCollection_Array1< opencascade::handle< StepRepr_RepresentationItem > > &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepRepr_RepresentationItem > > &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Set(self, *args)

    def First(self) -> "opencascade::handle< StepRepr_RepresentationItem > const &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepRepr_RepresentationItem > &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepRepr_RepresentationItem > const &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepRepr_RepresentationItem > &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_RepresentationItem > const &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_RepresentationItem > &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem > &":
        return _StepRepr.StepRepr_Array1OfRepresentationItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepRepr_RepresentationItem > const &") -> "void":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepRepr.StepRepr_Array1OfRepresentationItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepRepr.delete_StepRepr_Array1OfRepresentationItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepRepr_Array1OfRepresentationItem in _StepRepr:
_StepRepr.StepRepr_Array1OfRepresentationItem_swigregister(StepRepr_Array1OfRepresentationItem)

class StepRepr_Array1OfShapeAspect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepRepr_ShapeAspect > >::iterator":
        return _StepRepr.StepRepr_Array1OfShapeAspect_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepRepr_ShapeAspect > >::iterator":
        return _StepRepr.StepRepr_Array1OfShapeAspect_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepRepr_ShapeAspect > >::const_iterator":
        return _StepRepr.StepRepr_Array1OfShapeAspect_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepRepr_ShapeAspect > >::const_iterator":
        return _StepRepr.StepRepr_Array1OfShapeAspect_cend(self)

    def __init__(self, *args):
        _StepRepr.StepRepr_Array1OfShapeAspect_swiginit(self, _StepRepr.new_StepRepr_Array1OfShapeAspect(*args))

    def Init(self, theValue: "opencascade::handle< StepRepr_ShapeAspect > const &") -> "void":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfShapeAspect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfShapeAspect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_Array1OfShapeAspect_IsAllocated(self)

    def Assign(self, theOther: "StepRepr_Array1OfShapeAspect") -> "NCollection_Array1< opencascade::handle< StepRepr_ShapeAspect > > &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Assign(self, theOther)

    def Move(self, theOther: "StepRepr_Array1OfShapeAspect") -> "NCollection_Array1< opencascade::handle< StepRepr_ShapeAspect > > &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepRepr_ShapeAspect > > &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Set(self, *args)

    def First(self) -> "opencascade::handle< StepRepr_ShapeAspect > const &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepRepr_ShapeAspect > &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepRepr_ShapeAspect > const &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepRepr_ShapeAspect > &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_ShapeAspect > const &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_ShapeAspect > &":
        return _StepRepr.StepRepr_Array1OfShapeAspect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect > &":
        return _StepRepr.StepRepr_Array1OfShapeAspect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepRepr_ShapeAspect > const &") -> "void":
        return _StepRepr.StepRepr_Array1OfShapeAspect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepRepr.StepRepr_Array1OfShapeAspect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepRepr.delete_StepRepr_Array1OfShapeAspect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepRepr_Array1OfShapeAspect in _StepRepr:
_StepRepr.StepRepr_Array1OfShapeAspect_swigregister(StepRepr_Array1OfShapeAspect)

class StepRepr_SequenceOfMaterialPropertyRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< StepRepr_MaterialPropertyRepresentation > >::iterator":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< StepRepr_MaterialPropertyRepresentation > >::iterator":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< StepRepr_MaterialPropertyRepresentation > >::const_iterator":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< StepRepr_MaterialPropertyRepresentation > >::const_iterator":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_cend(self)

    def __init__(self, *args):
        _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_swiginit(self, _StepRepr.new_StepRepr_SequenceOfMaterialPropertyRepresentation(*args))

    def Size(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_IsEmpty(self)

    def Reverse(self) -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Clear(self, theAllocator)

    def Assign(self, theOther: "StepRepr_SequenceOfMaterialPropertyRepresentation") -> "NCollection_Sequence< opencascade::handle< StepRepr_MaterialPropertyRepresentation > > &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Assign(self, theOther)

    def Set(self, theOther: "StepRepr_SequenceOfMaterialPropertyRepresentation") -> "NCollection_Sequence< opencascade::handle< StepRepr_MaterialPropertyRepresentation > > &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "StepRepr_SequenceOfMaterialPropertyRepresentation") -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepRepr_MaterialPropertyRepresentation > &":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepRepr_MaterialPropertyRepresentation > const &") -> "void":
        return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _StepRepr.delete_StepRepr_SequenceOfMaterialPropertyRepresentation

    def __len__(self):
        return self.Size()


# Register StepRepr_SequenceOfMaterialPropertyRepresentation in _StepRepr:
_StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_swigregister(StepRepr_SequenceOfMaterialPropertyRepresentation)

def StepRepr_SequenceOfMaterialPropertyRepresentation_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _StepRepr.StepRepr_SequenceOfMaterialPropertyRepresentation_delNode(theNode, theAl)

class StepRepr_SequenceOfRepresentationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< StepRepr_RepresentationItem > >::iterator":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< StepRepr_RepresentationItem > >::iterator":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< StepRepr_RepresentationItem > >::const_iterator":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< StepRepr_RepresentationItem > >::const_iterator":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_cend(self)

    def __init__(self, *args):
        _StepRepr.StepRepr_SequenceOfRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_SequenceOfRepresentationItem(*args))

    def Size(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_IsEmpty(self)

    def Reverse(self) -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Clear(self, theAllocator)

    def Assign(self, theOther: "StepRepr_SequenceOfRepresentationItem") -> "NCollection_Sequence< opencascade::handle< StepRepr_RepresentationItem > > &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Assign(self, theOther)

    def Set(self, theOther: "StepRepr_SequenceOfRepresentationItem") -> "NCollection_Sequence< opencascade::handle< StepRepr_RepresentationItem > > &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "StepRepr_SequenceOfRepresentationItem") -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< StepRepr_RepresentationItem > const &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepRepr_RepresentationItem > &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepRepr_RepresentationItem > const &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepRepr_RepresentationItem > &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_RepresentationItem > const &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepRepr_RepresentationItem > &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem > &":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepRepr_RepresentationItem > const &") -> "void":
        return _StepRepr.StepRepr_SequenceOfRepresentationItem_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _StepRepr.delete_StepRepr_SequenceOfRepresentationItem

    def __len__(self):
        return self.Size()


# Register StepRepr_SequenceOfRepresentationItem in _StepRepr:
_StepRepr.StepRepr_SequenceOfRepresentationItem_swigregister(StepRepr_SequenceOfRepresentationItem)

def StepRepr_SequenceOfRepresentationItem_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _StepRepr.StepRepr_SequenceOfRepresentationItem_delNode(theNode, theAl)

class StepRepr_AssemblyComponentUsageSubstitute(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_swiginit(self, _StepRepr.new_StepRepr_AssemblyComponentUsageSubstitute(*args))

    def Base(self, *args) -> "opencascade::handle< StepRepr_AssemblyComponentUsage >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_AssemblyComponentUsage>

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_Base(self, *args)

    def Definition(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_Definition(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDef: TCollection_HAsciiString
        aBase: StepRepr_AssemblyComponentUsage
        aSubs: StepRepr_AssemblyComponentUsage

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_Name(self, *args)

    def SetBase(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aBase: StepRepr_AssemblyComponentUsage

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_SetBase(self, *args)

    def SetDefinition(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDef: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_SetDefinition(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_SetName(self, *args)

    def SetSubstitute(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSubstitute: StepRepr_AssemblyComponentUsage

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_SetSubstitute(self, *args)

    def Substitute(self, *args) -> "opencascade::handle< StepRepr_AssemblyComponentUsage >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_AssemblyComponentUsage>

        """
        return _StepRepr.StepRepr_AssemblyComponentUsageSubstitute_Substitute(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_AssemblyComponentUsageSubstitute_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_AssemblyComponentUsageSubstitute

# Register StepRepr_AssemblyComponentUsageSubstitute in _StepRepr:
_StepRepr.StepRepr_AssemblyComponentUsageSubstitute_swigregister(StepRepr_AssemblyComponentUsageSubstitute)

class StepRepr_CharacterizedDefinition(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_CharacterizedDefinition_swiginit(self, _StepRepr.new_StepRepr_CharacterizedDefinition(*args))

    def CharacterizedObject(self, *args) -> "opencascade::handle< StepBasic_CharacterizedObject >":
        r"""
        Returns value as characterizedobject (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_CharacterizedObject>

        """
        return _StepRepr.StepRepr_CharacterizedDefinition_CharacterizedObject(self, *args)

    def DocumentFile(self, *args) -> "opencascade::handle< StepBasic_DocumentFile >":
        r"""
        Returns value as documentfile (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DocumentFile>

        """
        return _StepRepr.StepRepr_CharacterizedDefinition_DocumentFile(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as productdefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepRepr.StepRepr_CharacterizedDefinition_ProductDefinition(self, *args)

    def ProductDefinitionRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        Returns value as productdefinitionrelationship (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepRepr.StepRepr_CharacterizedDefinition_ProductDefinitionRelationship(self, *args)

    def ProductDefinitionShape(self, *args) -> "opencascade::handle< StepRepr_ProductDefinitionShape >":
        r"""
        Returns value as productdefinitionshape (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ProductDefinitionShape>

        """
        return _StepRepr.StepRepr_CharacterizedDefinition_ProductDefinitionShape(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns value as shapeaspect (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepRepr.StepRepr_CharacterizedDefinition_ShapeAspect(self, *args)

    def ShapeAspectRelationship(self, *args) -> "opencascade::handle< StepRepr_ShapeAspectRelationship >":
        r"""
        Returns value as shapeaspectrelationship (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspectRelationship>

        """
        return _StepRepr.StepRepr_CharacterizedDefinition_ShapeAspectRelationship(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_CharacterizedDefinition

# Register StepRepr_CharacterizedDefinition in _StepRepr:
_StepRepr.StepRepr_CharacterizedDefinition_swigregister(StepRepr_CharacterizedDefinition)

class StepRepr_ConfigurationDesign(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ConfigurationDesign_swiginit(self, _StepRepr.new_StepRepr_ConfigurationDesign(*args))

    def Configuration(self, *args) -> "opencascade::handle< StepRepr_ConfigurationItem >":
        r"""
        Returns field configuration.

        Returns
        -------
        opencascade::handle<StepRepr_ConfigurationItem>

        """
        return _StepRepr.StepRepr_ConfigurationDesign_Configuration(self, *args)

    def Design(self, *args) -> "StepRepr_ConfigurationDesignItem":
        r"""
        Returns field design.

        Returns
        -------
        StepRepr_ConfigurationDesignItem

        """
        return _StepRepr.StepRepr_ConfigurationDesign_Design(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aConfiguration: StepRepr_ConfigurationItem
        aDesign: StepRepr_ConfigurationDesignItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationDesign_Init(self, *args)

    def SetConfiguration(self, *args) -> "void":
        r"""
        Set field configuration.

        Parameters
        ----------
        Configuration: StepRepr_ConfigurationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationDesign_SetConfiguration(self, *args)

    def SetDesign(self, *args) -> "void":
        r"""
        Set field design.

        Parameters
        ----------
        Design: StepRepr_ConfigurationDesignItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationDesign_SetDesign(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ConfigurationDesign_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ConfigurationDesign

# Register StepRepr_ConfigurationDesign in _StepRepr:
_StepRepr.StepRepr_ConfigurationDesign_swigregister(StepRepr_ConfigurationDesign)

class StepRepr_ConfigurationDesignItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ConfigurationDesignItem_swiginit(self, _StepRepr.new_StepRepr_ConfigurationDesignItem(*args))

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as productdefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepRepr.StepRepr_ConfigurationDesignItem_ProductDefinition(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepRepr.StepRepr_ConfigurationDesignItem_ProductDefinitionFormation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ConfigurationDesignItem

# Register StepRepr_ConfigurationDesignItem in _StepRepr:
_StepRepr.StepRepr_ConfigurationDesignItem_swigregister(StepRepr_ConfigurationDesignItem)

class StepRepr_ConfigurationEffectivity(OCC.Core.StepBasic.StepBasic_ProductDefinitionEffectivity):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ConfigurationEffectivity_swiginit(self, _StepRepr.new_StepRepr_ConfigurationEffectivity(*args))

    def Configuration(self, *args) -> "opencascade::handle< StepRepr_ConfigurationDesign >":
        r"""
        Returns field configuration.

        Returns
        -------
        opencascade::handle<StepRepr_ConfigurationDesign>

        """
        return _StepRepr.StepRepr_ConfigurationEffectivity_Configuration(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aEffectivity_Id: TCollection_HAsciiString
        aProductDefinitionEffectivity_Usage: StepBasic_ProductDefinitionRelationship
        aConfiguration: StepRepr_ConfigurationDesign

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationEffectivity_Init(self, *args)

    def SetConfiguration(self, *args) -> "void":
        r"""
        Set field configuration.

        Parameters
        ----------
        Configuration: StepRepr_ConfigurationDesign

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationEffectivity_SetConfiguration(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ConfigurationEffectivity_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ConfigurationEffectivity

# Register StepRepr_ConfigurationEffectivity in _StepRepr:
_StepRepr.StepRepr_ConfigurationEffectivity_swigregister(StepRepr_ConfigurationEffectivity)

class StepRepr_ConfigurationItem(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ConfigurationItem_swiginit(self, _StepRepr.new_StepRepr_ConfigurationItem(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ConfigurationItem_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepRepr.StepRepr_ConfigurationItem_HasDescription(self, *args)

    def HasPurpose(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field purpose is defined.

        Returns
        -------
        bool

        """
        return _StepRepr.StepRepr_ConfigurationItem_HasPurpose(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field id.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ConfigurationItem_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aItemConcept: StepRepr_ProductConcept
        hasPurpose: bool
        aPurpose: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationItem_Init(self, *args)

    def ItemConcept(self, *args) -> "opencascade::handle< StepRepr_ProductConcept >":
        r"""
        Returns field itemconcept.

        Returns
        -------
        opencascade::handle<StepRepr_ProductConcept>

        """
        return _StepRepr.StepRepr_ConfigurationItem_ItemConcept(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ConfigurationItem_Name(self, *args)

    def Purpose(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field purpose.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ConfigurationItem_Purpose(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationItem_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        Set field id.

        Parameters
        ----------
        Id: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationItem_SetId(self, *args)

    def SetItemConcept(self, *args) -> "void":
        r"""
        Set field itemconcept.

        Parameters
        ----------
        ItemConcept: StepRepr_ProductConcept

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationItem_SetItemConcept(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationItem_SetName(self, *args)

    def SetPurpose(self, *args) -> "void":
        r"""
        Set field purpose.

        Parameters
        ----------
        Purpose: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ConfigurationItem_SetPurpose(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ConfigurationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ConfigurationItem

# Register StepRepr_ConfigurationItem in _StepRepr:
_StepRepr.StepRepr_ConfigurationItem_swigregister(StepRepr_ConfigurationItem)

class StepRepr_DataEnvironment(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_DataEnvironment_swiginit(self, _StepRepr.new_StepRepr_DataEnvironment(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_DataEnvironment_Description(self, *args)

    def Elements(self, *args) -> "opencascade::handle< StepRepr_HArray1OfPropertyDefinitionRepresentation >":
        r"""
        Returns field elements.

        Returns
        -------
        opencascade::handle<StepRepr_HArray1OfPropertyDefinitionRepresentation>

        """
        return _StepRepr.StepRepr_DataEnvironment_Elements(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aElements: StepRepr_HArray1OfPropertyDefinitionRepresentation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_DataEnvironment_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_DataEnvironment_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_DataEnvironment_SetDescription(self, *args)

    def SetElements(self, *args) -> "void":
        r"""
        Set field elements.

        Parameters
        ----------
        Elements: StepRepr_HArray1OfPropertyDefinitionRepresentation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_DataEnvironment_SetElements(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_DataEnvironment_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_DataEnvironment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_DataEnvironment

# Register StepRepr_DataEnvironment in _StepRepr:
_StepRepr.StepRepr_DataEnvironment_swigregister(StepRepr_DataEnvironment)

class StepRepr_FunctionallyDefinedTransformation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a functionallydefinedtransformation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_FunctionallyDefinedTransformation_swiginit(self, _StepRepr.new_StepRepr_FunctionallyDefinedTransformation(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_FunctionallyDefinedTransformation_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_FunctionallyDefinedTransformation_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_FunctionallyDefinedTransformation_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_FunctionallyDefinedTransformation_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_FunctionallyDefinedTransformation_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_FunctionallyDefinedTransformation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_FunctionallyDefinedTransformation

# Register StepRepr_FunctionallyDefinedTransformation in _StepRepr:
_StepRepr.StepRepr_FunctionallyDefinedTransformation_swigregister(StepRepr_FunctionallyDefinedTransformation)

class StepRepr_ItemDefinedTransformation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ItemDefinedTransformation_swiginit(self, _StepRepr.new_StepRepr_ItemDefinedTransformation(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aTransformItem1: StepRepr_RepresentationItem
        aTransformItem2: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_SetName(self, *args)

    def SetTransformItem1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItem: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_SetTransformItem1(self, *args)

    def SetTransformItem2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItem: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_SetTransformItem2(self, *args)

    def TransformItem1(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_TransformItem1(self, *args)

    def TransformItem2(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepRepr.StepRepr_ItemDefinedTransformation_TransformItem2(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ItemDefinedTransformation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ItemDefinedTransformation

# Register StepRepr_ItemDefinedTransformation in _StepRepr:
_StepRepr.StepRepr_ItemDefinedTransformation_swigregister(StepRepr_ItemDefinedTransformation)

class StepRepr_MaterialDesignation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_MaterialDesignation_swiginit(self, _StepRepr.new_StepRepr_MaterialDesignation(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aOfDefinition: StepRepr_CharacterizedDefinition

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MaterialDesignation_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_MaterialDesignation_Name(self, *args)

    def OfDefinition(self, *args) -> "StepRepr_CharacterizedDefinition":
        r"""
        No available documentation.

        Returns
        -------
        StepRepr_CharacterizedDefinition

        """
        return _StepRepr.StepRepr_MaterialDesignation_OfDefinition(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MaterialDesignation_SetName(self, *args)

    def SetOfDefinition(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aOfDefinition: StepRepr_CharacterizedDefinition

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MaterialDesignation_SetOfDefinition(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_MaterialDesignation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_MaterialDesignation

# Register StepRepr_MaterialDesignation in _StepRepr:
_StepRepr.StepRepr_MaterialDesignation_swigregister(StepRepr_MaterialDesignation)

class StepRepr_ProductConcept(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ProductConcept_swiginit(self, _StepRepr.new_StepRepr_ProductConcept(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ProductConcept_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepRepr.StepRepr_ProductConcept_HasDescription(self, *args)

    def Id(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field id.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ProductConcept_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aId: TCollection_HAsciiString
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aMarketContext: StepBasic_ProductConceptContext

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ProductConcept_Init(self, *args)

    def MarketContext(self, *args) -> "opencascade::handle< StepBasic_ProductConceptContext >":
        r"""
        Returns field marketcontext.

        Returns
        -------
        opencascade::handle<StepBasic_ProductConceptContext>

        """
        return _StepRepr.StepRepr_ProductConcept_MarketContext(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ProductConcept_Name(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ProductConcept_SetDescription(self, *args)

    def SetId(self, *args) -> "void":
        r"""
        Set field id.

        Parameters
        ----------
        Id: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ProductConcept_SetId(self, *args)

    def SetMarketContext(self, *args) -> "void":
        r"""
        Set field marketcontext.

        Parameters
        ----------
        MarketContext: StepBasic_ProductConceptContext

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ProductConcept_SetMarketContext(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ProductConcept_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ProductConcept_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ProductConcept

# Register StepRepr_ProductConcept in _StepRepr:
_StepRepr.StepRepr_ProductConcept_swigregister(StepRepr_ProductConcept)

class StepRepr_ProductDefinitionUsage(OCC.Core.StepBasic.StepBasic_ProductDefinitionRelationship):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ProductDefinitionUsage_swiginit(self, _StepRepr.new_StepRepr_ProductDefinitionUsage(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ProductDefinitionUsage_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ProductDefinitionUsage

# Register StepRepr_ProductDefinitionUsage in _StepRepr:
_StepRepr.StepRepr_ProductDefinitionUsage_swigregister(StepRepr_ProductDefinitionUsage)

class StepRepr_PropertyDefinition(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_PropertyDefinition_swiginit(self, _StepRepr.new_StepRepr_PropertyDefinition(*args))

    def Definition(self, *args) -> "StepRepr_CharacterizedDefinition":
        r"""
        Returns field definition.

        Returns
        -------
        StepRepr_CharacterizedDefinition

        """
        return _StepRepr.StepRepr_PropertyDefinition_Definition(self, *args)

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_PropertyDefinition_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepRepr.StepRepr_PropertyDefinition_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aDefinition: StepRepr_CharacterizedDefinition

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinition_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_PropertyDefinition_Name(self, *args)

    def SetDefinition(self, *args) -> "void":
        r"""
        Set field definition.

        Parameters
        ----------
        Definition: StepRepr_CharacterizedDefinition

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinition_SetDefinition(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinition_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinition_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_PropertyDefinition_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_PropertyDefinition

# Register StepRepr_PropertyDefinition in _StepRepr:
_StepRepr.StepRepr_PropertyDefinition_swigregister(StepRepr_PropertyDefinition)

class StepRepr_PropertyDefinitionRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_PropertyDefinitionRelationship_swiginit(self, _StepRepr.new_StepRepr_PropertyDefinitionRelationship(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aRelatingPropertyDefinition: StepRepr_PropertyDefinition
        aRelatedPropertyDefinition: StepRepr_PropertyDefinition

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_Name(self, *args)

    def RelatedPropertyDefinition(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinition >":
        r"""
        Returns field relatedpropertydefinition.

        Returns
        -------
        opencascade::handle<StepRepr_PropertyDefinition>

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_RelatedPropertyDefinition(self, *args)

    def RelatingPropertyDefinition(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinition >":
        r"""
        Returns field relatingpropertydefinition.

        Returns
        -------
        opencascade::handle<StepRepr_PropertyDefinition>

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_RelatingPropertyDefinition(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_SetName(self, *args)

    def SetRelatedPropertyDefinition(self, *args) -> "void":
        r"""
        Set field relatedpropertydefinition.

        Parameters
        ----------
        RelatedPropertyDefinition: StepRepr_PropertyDefinition

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_SetRelatedPropertyDefinition(self, *args)

    def SetRelatingPropertyDefinition(self, *args) -> "void":
        r"""
        Set field relatingpropertydefinition.

        Parameters
        ----------
        RelatingPropertyDefinition: StepRepr_PropertyDefinition

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinitionRelationship_SetRelatingPropertyDefinition(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_PropertyDefinitionRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_PropertyDefinitionRelationship

# Register StepRepr_PropertyDefinitionRelationship in _StepRepr:
_StepRepr.StepRepr_PropertyDefinitionRelationship_swigregister(StepRepr_PropertyDefinitionRelationship)

class StepRepr_PropertyDefinitionRepresentation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_PropertyDefinitionRepresentation_swiginit(self, _StepRepr.new_StepRepr_PropertyDefinitionRepresentation(*args))

    def Definition(self, *args) -> "StepRepr_RepresentedDefinition":
        r"""
        Returns field definition.

        Returns
        -------
        StepRepr_RepresentedDefinition

        """
        return _StepRepr.StepRepr_PropertyDefinitionRepresentation_Definition(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aDefinition: StepRepr_RepresentedDefinition
        aUsedRepresentation: StepRepr_Representation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinitionRepresentation_Init(self, *args)

    def SetDefinition(self, *args) -> "void":
        r"""
        Set field definition.

        Parameters
        ----------
        Definition: StepRepr_RepresentedDefinition

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinitionRepresentation_SetDefinition(self, *args)

    def SetUsedRepresentation(self, *args) -> "void":
        r"""
        Set field usedrepresentation.

        Parameters
        ----------
        UsedRepresentation: StepRepr_Representation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_PropertyDefinitionRepresentation_SetUsedRepresentation(self, *args)

    def UsedRepresentation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        Returns field usedrepresentation.

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepRepr.StepRepr_PropertyDefinitionRepresentation_UsedRepresentation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_PropertyDefinitionRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_PropertyDefinitionRepresentation

# Register StepRepr_PropertyDefinitionRepresentation in _StepRepr:
_StepRepr.StepRepr_PropertyDefinitionRepresentation_swigregister(StepRepr_PropertyDefinitionRepresentation)

class StepRepr_Representation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a representation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_Representation_swiginit(self, _StepRepr.new_StepRepr_Representation(*args))

    def ContextOfItems(self, *args) -> "opencascade::handle< StepRepr_RepresentationContext >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationContext>

        """
        return _StepRepr.StepRepr_Representation_ContextOfItems(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aItems: StepRepr_HArray1OfRepresentationItem
        aContextOfItems: StepRepr_RepresentationContext

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_Representation_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepRepr_HArray1OfRepresentationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_HArray1OfRepresentationItem>

        """
        return _StepRepr.StepRepr_Representation_Items(self, *args)

    def ItemsValue(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepRepr.StepRepr_Representation_ItemsValue(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_Representation_Name(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepRepr.StepRepr_Representation_NbItems(self, *args)

    def SetContextOfItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aContextOfItems: StepRepr_RepresentationContext

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_Representation_SetContextOfItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepRepr_HArray1OfRepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_Representation_SetItems(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_Representation_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_Representation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_Representation

# Register StepRepr_Representation in _StepRepr:
_StepRepr.StepRepr_Representation_swigregister(StepRepr_Representation)

class StepRepr_RepresentationContext(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a representationcontext.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_RepresentationContext_swiginit(self, _StepRepr.new_StepRepr_RepresentationContext(*args))

    def ContextIdentifier(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_RepresentationContext_ContextIdentifier(self, *args)

    def ContextType(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_RepresentationContext_ContextType(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aContextIdentifier: TCollection_HAsciiString
        aContextType: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationContext_Init(self, *args)

    def SetContextIdentifier(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aContextIdentifier: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationContext_SetContextIdentifier(self, *args)

    def SetContextType(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aContextType: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationContext_SetContextType(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_RepresentationContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_RepresentationContext

# Register StepRepr_RepresentationContext in _StepRepr:
_StepRepr.StepRepr_RepresentationContext_swigregister(StepRepr_RepresentationContext)

class StepRepr_RepresentationItem(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a representationitem.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_RepresentationItem_swiginit(self, _StepRepr.new_StepRepr_RepresentationItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationItem_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_RepresentationItem_Name(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationItem_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_RepresentationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_RepresentationItem

# Register StepRepr_RepresentationItem in _StepRepr:
_StepRepr.StepRepr_RepresentationItem_swigregister(StepRepr_RepresentationItem)

class StepRepr_RepresentationMap(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a representationmap.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_RepresentationMap_swiginit(self, _StepRepr.new_StepRepr_RepresentationMap(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMappingOrigin: StepRepr_RepresentationItem
        aMappedRepresentation: StepRepr_Representation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationMap_Init(self, *args)

    def MappedRepresentation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepRepr.StepRepr_RepresentationMap_MappedRepresentation(self, *args)

    def MappingOrigin(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepRepr.StepRepr_RepresentationMap_MappingOrigin(self, *args)

    def SetMappedRepresentation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMappedRepresentation: StepRepr_Representation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationMap_SetMappedRepresentation(self, *args)

    def SetMappingOrigin(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMappingOrigin: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationMap_SetMappingOrigin(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_RepresentationMap_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_RepresentationMap

# Register StepRepr_RepresentationMap in _StepRepr:
_StepRepr.StepRepr_RepresentationMap_swigregister(StepRepr_RepresentationMap)

class StepRepr_RepresentationRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a representationrelationship.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_RepresentationRelationship_swiginit(self, _StepRepr.new_StepRepr_RepresentationRelationship(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_RepresentationRelationship_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aRep1: StepRepr_Representation
        aRep2: StepRepr_Representation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_RepresentationRelationship_Name(self, *args)

    def Rep1(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepRepr.StepRepr_RepresentationRelationship_Rep1(self, *args)

    def Rep2(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepRepr.StepRepr_RepresentationRelationship_Rep2(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationRelationship_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationRelationship_SetName(self, *args)

    def SetRep1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRep1: StepRepr_Representation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationRelationship_SetRep1(self, *args)

    def SetRep2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aRep2: StepRepr_Representation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationRelationship_SetRep2(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_RepresentationRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_RepresentationRelationship

# Register StepRepr_RepresentationRelationship in _StepRepr:
_StepRepr.StepRepr_RepresentationRelationship_swigregister(StepRepr_RepresentationRelationship)

class StepRepr_RepresentedDefinition(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_RepresentedDefinition_swiginit(self, _StepRepr.new_StepRepr_RepresentedDefinition(*args))

    def GeneralProperty(self, *args) -> "opencascade::handle< StepBasic_GeneralProperty >":
        r"""
        Returns value as generalproperty (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_GeneralProperty>

        """
        return _StepRepr.StepRepr_RepresentedDefinition_GeneralProperty(self, *args)

    def PropertyDefinition(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinition >":
        r"""
        Returns value as propertydefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_PropertyDefinition>

        """
        return _StepRepr.StepRepr_RepresentedDefinition_PropertyDefinition(self, *args)

    def PropertyDefinitionRelationship(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinitionRelationship >":
        r"""
        Returns value as propertydefinitionrelationship (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_PropertyDefinitionRelationship>

        """
        return _StepRepr.StepRepr_RepresentedDefinition_PropertyDefinitionRelationship(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns value as shapeaspect (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepRepr.StepRepr_RepresentedDefinition_ShapeAspect(self, *args)

    def ShapeAspectRelationship(self, *args) -> "opencascade::handle< StepRepr_ShapeAspectRelationship >":
        r"""
        Returns value as shapeaspectrelationship (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspectRelationship>

        """
        return _StepRepr.StepRepr_RepresentedDefinition_ShapeAspectRelationship(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_RepresentedDefinition

# Register StepRepr_RepresentedDefinition in _StepRepr:
_StepRepr.StepRepr_RepresentedDefinition_swigregister(StepRepr_RepresentedDefinition)

class StepRepr_ShapeAspect(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a shapeaspect.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ShapeAspect_swiginit(self, _StepRepr.new_StepRepr_ShapeAspect(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ShapeAspect_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aOfShape: StepRepr_ProductDefinitionShape
        aProductDefinitional: StepData_Logical

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspect_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ShapeAspect_Name(self, *args)

    def OfShape(self, *args) -> "opencascade::handle< StepRepr_ProductDefinitionShape >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_ProductDefinitionShape>

        """
        return _StepRepr.StepRepr_ShapeAspect_OfShape(self, *args)

    def ProductDefinitional(self, *args) -> "StepData_Logical":
        r"""
        No available documentation.

        Returns
        -------
        StepData_Logical

        """
        return _StepRepr.StepRepr_ShapeAspect_ProductDefinitional(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspect_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspect_SetName(self, *args)

    def SetOfShape(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aOfShape: StepRepr_ProductDefinitionShape

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspect_SetOfShape(self, *args)

    def SetProductDefinitional(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aProductDefinitional: StepData_Logical

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspect_SetProductDefinitional(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ShapeAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ShapeAspect

# Register StepRepr_ShapeAspect in _StepRepr:
_StepRepr.StepRepr_ShapeAspect_swigregister(StepRepr_ShapeAspect)

class StepRepr_ShapeAspectRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ShapeAspectRelationship_swiginit(self, _StepRepr.new_StepRepr_ShapeAspectRelationship(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_Description(self, *args)

    def HasDescription(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field description is defined.

        Returns
        -------
        bool

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_HasDescription(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aName: TCollection_HAsciiString
        hasDescription: bool
        aDescription: TCollection_HAsciiString
        aRelatingShapeAspect: StepRepr_ShapeAspect
        aRelatedShapeAspect: StepRepr_ShapeAspect

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_Init(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_Name(self, *args)

    def RelatedShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns field relatedshapeaspect.

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_RelatedShapeAspect(self, *args)

    def RelatingShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns field relatingshapeaspect.

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_RelatingShapeAspect(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_SetDescription(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Set field name.

        Parameters
        ----------
        Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_SetName(self, *args)

    def SetRelatedShapeAspect(self, *args) -> "void":
        r"""
        Set field relatedshapeaspect.

        Parameters
        ----------
        RelatedShapeAspect: StepRepr_ShapeAspect

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_SetRelatedShapeAspect(self, *args)

    def SetRelatingShapeAspect(self, *args) -> "void":
        r"""
        Set field relatingshapeaspect.

        Parameters
        ----------
        RelatingShapeAspect: StepRepr_ShapeAspect

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ShapeAspectRelationship_SetRelatingShapeAspect(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ShapeAspectRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ShapeAspectRelationship

# Register StepRepr_ShapeAspectRelationship in _StepRepr:
_StepRepr.StepRepr_ShapeAspectRelationship_swigregister(StepRepr_ShapeAspectRelationship)

class StepRepr_ShapeDefinition(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a shapedefinition selecttype.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ShapeDefinition_swiginit(self, _StepRepr.new_StepRepr_ShapeDefinition(*args))

    def ProductDefinitionShape(self, *args) -> "opencascade::handle< StepRepr_ProductDefinitionShape >":
        r"""
        Returns value as a productdefinitionshape (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ProductDefinitionShape>

        """
        return _StepRepr.StepRepr_ShapeDefinition_ProductDefinitionShape(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns value as a shapeaspect (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepRepr.StepRepr_ShapeDefinition_ShapeAspect(self, *args)

    def ShapeAspectRelationship(self, *args) -> "opencascade::handle< StepRepr_ShapeAspectRelationship >":
        r"""
        Returns value as a shapeaspectrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspectRelationship>

        """
        return _StepRepr.StepRepr_ShapeDefinition_ShapeAspectRelationship(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ShapeDefinition

# Register StepRepr_ShapeDefinition in _StepRepr:
_StepRepr.StepRepr_ShapeDefinition_swigregister(StepRepr_ShapeDefinition)

class StepRepr_SuppliedPartRelationship(OCC.Core.StepBasic.StepBasic_ProductDefinitionRelationship):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_SuppliedPartRelationship_swiginit(self, _StepRepr.new_StepRepr_SuppliedPartRelationship(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_SuppliedPartRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_SuppliedPartRelationship

# Register StepRepr_SuppliedPartRelationship in _StepRepr:
_StepRepr.StepRepr_SuppliedPartRelationship_swigregister(StepRepr_SuppliedPartRelationship)

class StepRepr_Transformation(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a transformation selecttype.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_Transformation_swiginit(self, _StepRepr.new_StepRepr_Transformation(*args))

    def FunctionallyDefinedTransformation(self, *args) -> "opencascade::handle< StepRepr_FunctionallyDefinedTransformation >":
        r"""
        Returns value as a functionallydefinedtransformation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_FunctionallyDefinedTransformation>

        """
        return _StepRepr.StepRepr_Transformation_FunctionallyDefinedTransformation(self, *args)

    def ItemDefinedTransformation(self, *args) -> "opencascade::handle< StepRepr_ItemDefinedTransformation >":
        r"""
        Returns value as a itemdefinedtransformation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ItemDefinedTransformation>

        """
        return _StepRepr.StepRepr_Transformation_ItemDefinedTransformation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_Transformation

# Register StepRepr_Transformation in _StepRepr:
_StepRepr.StepRepr_Transformation_swigregister(StepRepr_Transformation)

class StepRepr_AssemblyComponentUsage(StepRepr_ProductDefinitionUsage):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_AssemblyComponentUsage_swiginit(self, _StepRepr.new_StepRepr_AssemblyComponentUsage(*args))

    def HasReferenceDesignator(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if optional field referencedesignator is defined.

        Returns
        -------
        bool

        """
        return _StepRepr.StepRepr_AssemblyComponentUsage_HasReferenceDesignator(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aProductDefinitionRelationship_Id: TCollection_HAsciiString
        aProductDefinitionRelationship_Name: TCollection_HAsciiString
        hasProductDefinitionRelationship_Description: bool
        aProductDefinitionRelationship_Description: TCollection_HAsciiString
        aProductDefinitionRelationship_RelatingProductDefinition: StepBasic_ProductDefinition
        aProductDefinitionRelationship_RelatedProductDefinition: StepBasic_ProductDefinition
        hasReferenceDesignator: bool
        aReferenceDesignator: TCollection_HAsciiString

        Returns
        -------
        None
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aProductDefinitionRelationship_Id: TCollection_HAsciiString
        aProductDefinitionRelationship_Name: TCollection_HAsciiString
        hasProductDefinitionRelationship_Description: bool
        aProductDefinitionRelationship_Description: TCollection_HAsciiString
        aProductDefinitionRelationship_RelatingProductDefinition: StepBasic_ProductDefinitionOrReference
        aProductDefinitionRelationship_RelatedProductDefinition: StepBasic_ProductDefinitionOrReference
        hasReferenceDesignator: bool
        aReferenceDesignator: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_AssemblyComponentUsage_Init(self, *args)

    def ReferenceDesignator(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field referencedesignator.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_AssemblyComponentUsage_ReferenceDesignator(self, *args)

    def SetReferenceDesignator(self, *args) -> "void":
        r"""
        Set field referencedesignator.

        Parameters
        ----------
        ReferenceDesignator: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_AssemblyComponentUsage_SetReferenceDesignator(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_AssemblyComponentUsage_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_AssemblyComponentUsage

# Register StepRepr_AssemblyComponentUsage in _StepRepr:
_StepRepr.StepRepr_AssemblyComponentUsage_swigregister(StepRepr_AssemblyComponentUsage)

class StepRepr_CharacterizedRepresentation(StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_CharacterizedRepresentation_swiginit(self, _StepRepr.new_StepRepr_CharacterizedRepresentation(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_CharacterizedRepresentation_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Returns a characterizedrepresentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theDescription: TCollection_HAsciiString
        theItems: StepRepr_HArray1OfRepresentationItem
        theContextOfItems: StepRepr_RepresentationContext

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_CharacterizedRepresentation_Init(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_CharacterizedRepresentation_SetDescription(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_CharacterizedRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_CharacterizedRepresentation

# Register StepRepr_CharacterizedRepresentation in _StepRepr:
_StepRepr.StepRepr_CharacterizedRepresentation_swigregister(StepRepr_CharacterizedRepresentation)

class StepRepr_CompShAspAndDatumFeatAndShAsp(StepRepr_ShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_CompShAspAndDatumFeatAndShAsp_swiginit(self, _StepRepr.new_StepRepr_CompShAspAndDatumFeatAndShAsp(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_CompShAspAndDatumFeatAndShAsp_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_CompShAspAndDatumFeatAndShAsp

# Register StepRepr_CompShAspAndDatumFeatAndShAsp in _StepRepr:
_StepRepr.StepRepr_CompShAspAndDatumFeatAndShAsp_swigregister(StepRepr_CompShAspAndDatumFeatAndShAsp)

class StepRepr_CompositeShapeAspect(StepRepr_ShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_CompositeShapeAspect_swiginit(self, _StepRepr.new_StepRepr_CompositeShapeAspect(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_CompositeShapeAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_CompositeShapeAspect

# Register StepRepr_CompositeShapeAspect in _StepRepr:
_StepRepr.StepRepr_CompositeShapeAspect_swigregister(StepRepr_CompositeShapeAspect)

class StepRepr_CompoundRepresentationItem(StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_CompoundRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_CompoundRepresentationItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        item_element: StepRepr_HArray1OfRepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_CompoundRepresentationItem_Init(self, *args)

    def ItemElement(self, *args) -> "opencascade::handle< StepRepr_HArray1OfRepresentationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_HArray1OfRepresentationItem>

        """
        return _StepRepr.StepRepr_CompoundRepresentationItem_ItemElement(self, *args)

    def ItemElementValue(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepRepr.StepRepr_CompoundRepresentationItem_ItemElementValue(self, *args)

    def NbItemElement(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepRepr.StepRepr_CompoundRepresentationItem_NbItemElement(self, *args)

    def SetItemElement(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        item_element: StepRepr_HArray1OfRepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_CompoundRepresentationItem_SetItemElement(self, *args)

    def SetItemElementValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int
        anelement: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_CompoundRepresentationItem_SetItemElementValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_CompoundRepresentationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_CompoundRepresentationItem

# Register StepRepr_CompoundRepresentationItem in _StepRepr:
_StepRepr.StepRepr_CompoundRepresentationItem_swigregister(StepRepr_CompoundRepresentationItem)

class StepRepr_ConstructiveGeometryRepresentation(StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a constructivegeometryrepresentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ConstructiveGeometryRepresentation_swiginit(self, _StepRepr.new_StepRepr_ConstructiveGeometryRepresentation(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ConstructiveGeometryRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ConstructiveGeometryRepresentation

# Register StepRepr_ConstructiveGeometryRepresentation in _StepRepr:
_StepRepr.StepRepr_ConstructiveGeometryRepresentation_swigregister(StepRepr_ConstructiveGeometryRepresentation)

class StepRepr_ConstructiveGeometryRepresentationRelationship(StepRepr_RepresentationRelationship):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ConstructiveGeometryRepresentationRelationship_swiginit(self, _StepRepr.new_StepRepr_ConstructiveGeometryRepresentationRelationship(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ConstructiveGeometryRepresentationRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ConstructiveGeometryRepresentationRelationship

# Register StepRepr_ConstructiveGeometryRepresentationRelationship in _StepRepr:
_StepRepr.StepRepr_ConstructiveGeometryRepresentationRelationship_swigregister(StepRepr_ConstructiveGeometryRepresentationRelationship)

class StepRepr_DefinitionalRepresentation(StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a definitionalrepresentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_DefinitionalRepresentation_swiginit(self, _StepRepr.new_StepRepr_DefinitionalRepresentation(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_DefinitionalRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_DefinitionalRepresentation

# Register StepRepr_DefinitionalRepresentation in _StepRepr:
_StepRepr.StepRepr_DefinitionalRepresentation_swigregister(StepRepr_DefinitionalRepresentation)

class StepRepr_DerivedShapeAspect(StepRepr_ShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_DerivedShapeAspect_swiginit(self, _StepRepr.new_StepRepr_DerivedShapeAspect(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_DerivedShapeAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_DerivedShapeAspect

# Register StepRepr_DerivedShapeAspect in _StepRepr:
_StepRepr.StepRepr_DerivedShapeAspect_swigregister(StepRepr_DerivedShapeAspect)

class StepRepr_DescriptiveRepresentationItem(StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a descriptiverepresentationitem.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_DescriptiveRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_DescriptiveRepresentationItem(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_DescriptiveRepresentationItem_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_DescriptiveRepresentationItem_Init(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_DescriptiveRepresentationItem_SetDescription(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_DescriptiveRepresentationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_DescriptiveRepresentationItem

# Register StepRepr_DescriptiveRepresentationItem in _StepRepr:
_StepRepr.StepRepr_DescriptiveRepresentationItem_swigregister(StepRepr_DescriptiveRepresentationItem)

class StepRepr_ExternallyDefinedRepresentation(StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ExternallyDefinedRepresentation_swiginit(self, _StepRepr.new_StepRepr_ExternallyDefinedRepresentation(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ExternallyDefinedRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ExternallyDefinedRepresentation

# Register StepRepr_ExternallyDefinedRepresentation in _StepRepr:
_StepRepr.StepRepr_ExternallyDefinedRepresentation_swigregister(StepRepr_ExternallyDefinedRepresentation)

class StepRepr_FeatureForDatumTargetRelationship(StepRepr_ShapeAspectRelationship):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_FeatureForDatumTargetRelationship_swiginit(self, _StepRepr.new_StepRepr_FeatureForDatumTargetRelationship(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_FeatureForDatumTargetRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_FeatureForDatumTargetRelationship

# Register StepRepr_FeatureForDatumTargetRelationship in _StepRepr:
_StepRepr.StepRepr_FeatureForDatumTargetRelationship_swigregister(StepRepr_FeatureForDatumTargetRelationship)

class StepRepr_GlobalUncertaintyAssignedContext(StepRepr_RepresentationContext):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a globaluncertaintyassignedcontext.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_GlobalUncertaintyAssignedContext_swiginit(self, _StepRepr.new_StepRepr_GlobalUncertaintyAssignedContext(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aContextIdentifier: TCollection_HAsciiString
        aContextType: TCollection_HAsciiString
        aUncertainty: StepBasic_HArray1OfUncertaintyMeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_GlobalUncertaintyAssignedContext_Init(self, *args)

    def NbUncertainty(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepRepr.StepRepr_GlobalUncertaintyAssignedContext_NbUncertainty(self, *args)

    def SetUncertainty(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUncertainty: StepBasic_HArray1OfUncertaintyMeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_GlobalUncertaintyAssignedContext_SetUncertainty(self, *args)

    def Uncertainty(self, *args) -> "opencascade::handle< StepBasic_HArray1OfUncertaintyMeasureWithUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfUncertaintyMeasureWithUnit>

        """
        return _StepRepr.StepRepr_GlobalUncertaintyAssignedContext_Uncertainty(self, *args)

    def UncertaintyValue(self, *args) -> "opencascade::handle< StepBasic_UncertaintyMeasureWithUnit >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_UncertaintyMeasureWithUnit>

        """
        return _StepRepr.StepRepr_GlobalUncertaintyAssignedContext_UncertaintyValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_GlobalUncertaintyAssignedContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_GlobalUncertaintyAssignedContext

# Register StepRepr_GlobalUncertaintyAssignedContext in _StepRepr:
_StepRepr.StepRepr_GlobalUncertaintyAssignedContext_swigregister(StepRepr_GlobalUncertaintyAssignedContext)

class StepRepr_GlobalUnitAssignedContext(StepRepr_RepresentationContext):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a globalunitassignedcontext.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_GlobalUnitAssignedContext_swiginit(self, _StepRepr.new_StepRepr_GlobalUnitAssignedContext(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aContextIdentifier: TCollection_HAsciiString
        aContextType: TCollection_HAsciiString
        aUnits: StepBasic_HArray1OfNamedUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_GlobalUnitAssignedContext_Init(self, *args)

    def NbUnits(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepRepr.StepRepr_GlobalUnitAssignedContext_NbUnits(self, *args)

    def SetUnits(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aUnits: StepBasic_HArray1OfNamedUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_GlobalUnitAssignedContext_SetUnits(self, *args)

    def Units(self, *args) -> "opencascade::handle< StepBasic_HArray1OfNamedUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfNamedUnit>

        """
        return _StepRepr.StepRepr_GlobalUnitAssignedContext_Units(self, *args)

    def UnitsValue(self, *args) -> "opencascade::handle< StepBasic_NamedUnit >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_NamedUnit>

        """
        return _StepRepr.StepRepr_GlobalUnitAssignedContext_UnitsValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_GlobalUnitAssignedContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_GlobalUnitAssignedContext

# Register StepRepr_GlobalUnitAssignedContext in _StepRepr:
_StepRepr.StepRepr_GlobalUnitAssignedContext_swigregister(StepRepr_GlobalUnitAssignedContext)

class StepRepr_IntegerRepresentationItem(StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a integerrepresentationitem.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_IntegerRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_IntegerRepresentationItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theValue: int

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_IntegerRepresentationItem_Init(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: int

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_IntegerRepresentationItem_SetValue(self, *args)

    def Value(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepRepr.StepRepr_IntegerRepresentationItem_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_IntegerRepresentationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_IntegerRepresentationItem

# Register StepRepr_IntegerRepresentationItem in _StepRepr:
_StepRepr.StepRepr_IntegerRepresentationItem_swigregister(StepRepr_IntegerRepresentationItem)

class StepRepr_MakeFromUsageOption(StepRepr_ProductDefinitionUsage):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_MakeFromUsageOption_swiginit(self, _StepRepr.new_StepRepr_MakeFromUsageOption(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aProductDefinitionRelationship_Id: TCollection_HAsciiString
        aProductDefinitionRelationship_Name: TCollection_HAsciiString
        hasProductDefinitionRelationship_Description: bool
        aProductDefinitionRelationship_Description: TCollection_HAsciiString
        aProductDefinitionRelationship_RelatingProductDefinition: StepBasic_ProductDefinition
        aProductDefinitionRelationship_RelatedProductDefinition: StepBasic_ProductDefinition
        aRanking: int
        aRankingRationale: TCollection_HAsciiString
        aQuantity: StepBasic_MeasureWithUnit

        Returns
        -------
        None
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aProductDefinitionRelationship_Id: TCollection_HAsciiString
        aProductDefinitionRelationship_Name: TCollection_HAsciiString
        hasProductDefinitionRelationship_Description: bool
        aProductDefinitionRelationship_Description: TCollection_HAsciiString
        aProductDefinitionRelationship_RelatingProductDefinition: StepBasic_ProductDefinitionOrReference
        aProductDefinitionRelationship_RelatedProductDefinition: StepBasic_ProductDefinitionOrReference
        aRanking: int
        aRankingRationale: TCollection_HAsciiString
        aQuantity: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MakeFromUsageOption_Init(self, *args)

    def Quantity(self, *args) -> "opencascade::handle< StepBasic_MeasureWithUnit >":
        r"""
        Returns field quantity.

        Returns
        -------
        opencascade::handle<StepBasic_MeasureWithUnit>

        """
        return _StepRepr.StepRepr_MakeFromUsageOption_Quantity(self, *args)

    def Ranking(self, *args) -> "Standard_Integer":
        r"""
        Returns field ranking.

        Returns
        -------
        int

        """
        return _StepRepr.StepRepr_MakeFromUsageOption_Ranking(self, *args)

    def RankingRationale(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field rankingrationale.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepRepr.StepRepr_MakeFromUsageOption_RankingRationale(self, *args)

    def SetQuantity(self, *args) -> "void":
        r"""
        Set field quantity.

        Parameters
        ----------
        Quantity: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MakeFromUsageOption_SetQuantity(self, *args)

    def SetRanking(self, *args) -> "void":
        r"""
        Set field ranking.

        Parameters
        ----------
        Ranking: int

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MakeFromUsageOption_SetRanking(self, *args)

    def SetRankingRationale(self, *args) -> "void":
        r"""
        Set field rankingrationale.

        Parameters
        ----------
        RankingRationale: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MakeFromUsageOption_SetRankingRationale(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_MakeFromUsageOption_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_MakeFromUsageOption

# Register StepRepr_MakeFromUsageOption in _StepRepr:
_StepRepr.StepRepr_MakeFromUsageOption_swigregister(StepRepr_MakeFromUsageOption)

class StepRepr_MappedItem(StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a mappeditem.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_MappedItem_swiginit(self, _StepRepr.new_StepRepr_MappedItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aMappingSource: StepRepr_RepresentationMap
        aMappingTarget: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MappedItem_Init(self, *args)

    def MappingSource(self, *args) -> "opencascade::handle< StepRepr_RepresentationMap >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationMap>

        """
        return _StepRepr.StepRepr_MappedItem_MappingSource(self, *args)

    def MappingTarget(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepRepr.StepRepr_MappedItem_MappingTarget(self, *args)

    def SetMappingSource(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMappingSource: StepRepr_RepresentationMap

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MappedItem_SetMappingSource(self, *args)

    def SetMappingTarget(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMappingTarget: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MappedItem_SetMappingTarget(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_MappedItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_MappedItem

# Register StepRepr_MappedItem in _StepRepr:
_StepRepr.StepRepr_MappedItem_swigregister(StepRepr_MappedItem)

class StepRepr_MaterialProperty(StepRepr_PropertyDefinition):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_MaterialProperty_swiginit(self, _StepRepr.new_StepRepr_MaterialProperty(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_MaterialProperty_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_MaterialProperty

# Register StepRepr_MaterialProperty in _StepRepr:
_StepRepr.StepRepr_MaterialProperty_swigregister(StepRepr_MaterialProperty)

class StepRepr_MaterialPropertyRepresentation(StepRepr_PropertyDefinitionRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_MaterialPropertyRepresentation_swiginit(self, _StepRepr.new_StepRepr_MaterialPropertyRepresentation(*args))

    def DependentEnvironment(self, *args) -> "opencascade::handle< StepRepr_DataEnvironment >":
        r"""
        Returns field dependentenvironment.

        Returns
        -------
        opencascade::handle<StepRepr_DataEnvironment>

        """
        return _StepRepr.StepRepr_MaterialPropertyRepresentation_DependentEnvironment(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aPropertyDefinitionRepresentation_Definition: StepRepr_RepresentedDefinition
        aPropertyDefinitionRepresentation_UsedRepresentation: StepRepr_Representation
        aDependentEnvironment: StepRepr_DataEnvironment

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MaterialPropertyRepresentation_Init(self, *args)

    def SetDependentEnvironment(self, *args) -> "void":
        r"""
        Set field dependentenvironment.

        Parameters
        ----------
        DependentEnvironment: StepRepr_DataEnvironment

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MaterialPropertyRepresentation_SetDependentEnvironment(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_MaterialPropertyRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_MaterialPropertyRepresentation

# Register StepRepr_MaterialPropertyRepresentation in _StepRepr:
_StepRepr.StepRepr_MaterialPropertyRepresentation_swigregister(StepRepr_MaterialPropertyRepresentation)

class StepRepr_MeasureRepresentationItem(StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates empty object.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_MeasureRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_MeasureRepresentationItem(*args))

    def Init(self, *args) -> "void":
        r"""
        Init all fields.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aValueComponent: StepBasic_MeasureValueMember
        aUnitComponent: StepBasic_Unit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MeasureRepresentationItem_Init(self, *args)

    def Measure(self, *args) -> "opencascade::handle< StepBasic_MeasureWithUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_MeasureWithUnit>

        """
        return _StepRepr.StepRepr_MeasureRepresentationItem_Measure(self, *args)

    def SetMeasure(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Measure: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_MeasureRepresentationItem_SetMeasure(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_MeasureRepresentationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_MeasureRepresentationItem

# Register StepRepr_MeasureRepresentationItem in _StepRepr:
_StepRepr.StepRepr_MeasureRepresentationItem_swigregister(StepRepr_MeasureRepresentationItem)

class StepRepr_ParametricRepresentationContext(StepRepr_RepresentationContext):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a parametricrepresentationcontext.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ParametricRepresentationContext_swiginit(self, _StepRepr.new_StepRepr_ParametricRepresentationContext(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ParametricRepresentationContext_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ParametricRepresentationContext

# Register StepRepr_ParametricRepresentationContext in _StepRepr:
_StepRepr.StepRepr_ParametricRepresentationContext_swigregister(StepRepr_ParametricRepresentationContext)

class StepRepr_ProductDefinitionShape(StepRepr_PropertyDefinition):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ProductDefinitionShape_swiginit(self, _StepRepr.new_StepRepr_ProductDefinitionShape(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ProductDefinitionShape_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ProductDefinitionShape

# Register StepRepr_ProductDefinitionShape in _StepRepr:
_StepRepr.StepRepr_ProductDefinitionShape_swigregister(StepRepr_ProductDefinitionShape)

class StepRepr_ReprItemAndMeasureWithUnit(StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ReprItemAndMeasureWithUnit_swiginit(self, _StepRepr.new_StepRepr_ReprItemAndMeasureWithUnit(*args))

    def GetMeasureRepresentationItem(self, *args) -> "opencascade::handle< StepRepr_MeasureRepresentationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_MeasureRepresentationItem>

        """
        return _StepRepr.StepRepr_ReprItemAndMeasureWithUnit_GetMeasureRepresentationItem(self, *args)

    def GetMeasureWithUnit(self, *args) -> "opencascade::handle< StepBasic_MeasureWithUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_MeasureWithUnit>

        """
        return _StepRepr.StepRepr_ReprItemAndMeasureWithUnit_GetMeasureWithUnit(self, *args)

    def GetRepresentationItem(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepRepr.StepRepr_ReprItemAndMeasureWithUnit_GetRepresentationItem(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMWU: StepBasic_MeasureWithUnit
        aRI: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ReprItemAndMeasureWithUnit_Init(self, *args)

    def SetMeasureWithUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMWU: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ReprItemAndMeasureWithUnit_SetMeasureWithUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ReprItemAndMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ReprItemAndMeasureWithUnit

# Register StepRepr_ReprItemAndMeasureWithUnit in _StepRepr:
_StepRepr.StepRepr_ReprItemAndMeasureWithUnit_swigregister(StepRepr_ReprItemAndMeasureWithUnit)

class StepRepr_ShapeAspectDerivingRelationship(StepRepr_ShapeAspectRelationship):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ShapeAspectDerivingRelationship_swiginit(self, _StepRepr.new_StepRepr_ShapeAspectDerivingRelationship(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ShapeAspectDerivingRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ShapeAspectDerivingRelationship

# Register StepRepr_ShapeAspectDerivingRelationship in _StepRepr:
_StepRepr.StepRepr_ShapeAspectDerivingRelationship_swigregister(StepRepr_ShapeAspectDerivingRelationship)

class StepRepr_ShapeAspectTransition(StepRepr_ShapeAspectRelationship):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ShapeAspectTransition_swiginit(self, _StepRepr.new_StepRepr_ShapeAspectTransition(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ShapeAspectTransition_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ShapeAspectTransition

# Register StepRepr_ShapeAspectTransition in _StepRepr:
_StepRepr.StepRepr_ShapeAspectTransition_swigregister(StepRepr_ShapeAspectTransition)

class StepRepr_ShapeRepresentationRelationship(StepRepr_RepresentationRelationship):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ShapeRepresentationRelationship_swiginit(self, _StepRepr.new_StepRepr_ShapeRepresentationRelationship(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ShapeRepresentationRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ShapeRepresentationRelationship

# Register StepRepr_ShapeRepresentationRelationship in _StepRepr:
_StepRepr.StepRepr_ShapeRepresentationRelationship_swigregister(StepRepr_ShapeRepresentationRelationship)

class StepRepr_StructuralResponseProperty(StepRepr_PropertyDefinition):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_StructuralResponseProperty_swiginit(self, _StepRepr.new_StepRepr_StructuralResponseProperty(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_StructuralResponseProperty_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_StructuralResponseProperty

# Register StepRepr_StructuralResponseProperty in _StepRepr:
_StepRepr.StepRepr_StructuralResponseProperty_swigregister(StepRepr_StructuralResponseProperty)

class StepRepr_StructuralResponsePropertyDefinitionRepresentation(StepRepr_PropertyDefinitionRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_StructuralResponsePropertyDefinitionRepresentation_swiginit(self, _StepRepr.new_StepRepr_StructuralResponsePropertyDefinitionRepresentation(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_StructuralResponsePropertyDefinitionRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_StructuralResponsePropertyDefinitionRepresentation

# Register StepRepr_StructuralResponsePropertyDefinitionRepresentation in _StepRepr:
_StepRepr.StepRepr_StructuralResponsePropertyDefinitionRepresentation_swigregister(StepRepr_StructuralResponsePropertyDefinitionRepresentation)

class StepRepr_ValueRepresentationItem(StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a valuerepresentationitem.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ValueRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_ValueRepresentationItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theValueComponentMember: StepBasic_MeasureValueMember

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ValueRepresentationItem_Init(self, *args)

    def SetValueComponentMember(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theValueComponentMember: StepBasic_MeasureValueMember

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ValueRepresentationItem_SetValueComponentMember(self, *args)

    def ValueComponentMember(self, *args) -> "opencascade::handle< StepBasic_MeasureValueMember >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_MeasureValueMember>

        """
        return _StepRepr.StepRepr_ValueRepresentationItem_ValueComponentMember(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ValueRepresentationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ValueRepresentationItem

# Register StepRepr_ValueRepresentationItem in _StepRepr:
_StepRepr.StepRepr_ValueRepresentationItem_swigregister(StepRepr_ValueRepresentationItem)

class StepRepr_Apex(StepRepr_DerivedShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_Apex_swiginit(self, _StepRepr.new_StepRepr_Apex(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_Apex_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_Apex

# Register StepRepr_Apex in _StepRepr:
_StepRepr.StepRepr_Apex_swigregister(StepRepr_Apex)

class StepRepr_CentreOfSymmetry(StepRepr_DerivedShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_CentreOfSymmetry_swiginit(self, _StepRepr.new_StepRepr_CentreOfSymmetry(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_CentreOfSymmetry_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_CentreOfSymmetry

# Register StepRepr_CentreOfSymmetry in _StepRepr:
_StepRepr.StepRepr_CentreOfSymmetry_swigregister(StepRepr_CentreOfSymmetry)

class StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp(StepRepr_CompShAspAndDatumFeatAndShAsp):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_swiginit(self, _StepRepr.new_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp

# Register StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp in _StepRepr:
_StepRepr.StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp_swigregister(StepRepr_CompGroupShAspAndCompShAspAndDatumFeatAndShAsp)

class StepRepr_CompositeGroupShapeAspect(StepRepr_CompositeShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_CompositeGroupShapeAspect_swiginit(self, _StepRepr.new_StepRepr_CompositeGroupShapeAspect(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_CompositeGroupShapeAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_CompositeGroupShapeAspect

# Register StepRepr_CompositeGroupShapeAspect in _StepRepr:
_StepRepr.StepRepr_CompositeGroupShapeAspect_swigregister(StepRepr_CompositeGroupShapeAspect)

class StepRepr_ContinuosShapeAspect(StepRepr_CompositeShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ContinuosShapeAspect_swiginit(self, _StepRepr.new_StepRepr_ContinuosShapeAspect(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ContinuosShapeAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ContinuosShapeAspect

# Register StepRepr_ContinuosShapeAspect in _StepRepr:
_StepRepr.StepRepr_ContinuosShapeAspect_swigregister(StepRepr_ContinuosShapeAspect)

class StepRepr_Extension(StepRepr_DerivedShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_Extension_swiginit(self, _StepRepr.new_StepRepr_Extension(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_Extension_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_Extension

# Register StepRepr_Extension in _StepRepr:
_StepRepr.StepRepr_Extension_swigregister(StepRepr_Extension)

class StepRepr_GeometricAlignment(StepRepr_DerivedShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_GeometricAlignment_swiginit(self, _StepRepr.new_StepRepr_GeometricAlignment(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_GeometricAlignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_GeometricAlignment

# Register StepRepr_GeometricAlignment in _StepRepr:
_StepRepr.StepRepr_GeometricAlignment_swigregister(StepRepr_GeometricAlignment)

class StepRepr_NextAssemblyUsageOccurrence(StepRepr_AssemblyComponentUsage):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_NextAssemblyUsageOccurrence_swiginit(self, _StepRepr.new_StepRepr_NextAssemblyUsageOccurrence(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_NextAssemblyUsageOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_NextAssemblyUsageOccurrence

# Register StepRepr_NextAssemblyUsageOccurrence in _StepRepr:
_StepRepr.StepRepr_NextAssemblyUsageOccurrence_swigregister(StepRepr_NextAssemblyUsageOccurrence)

class StepRepr_ParallelOffset(StepRepr_DerivedShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ParallelOffset_swiginit(self, _StepRepr.new_StepRepr_ParallelOffset(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        theName: TCollection_HAsciiString
        theDescription: TCollection_HAsciiString
        theOfShape: StepRepr_ProductDefinitionShape
        theProductDefinitional: StepData_Logical
        theOffset: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ParallelOffset_Init(self, *args)

    def Offset(self, *args) -> "opencascade::handle< StepBasic_MeasureWithUnit >":
        r"""
        Returns field offset .

        Returns
        -------
        opencascade::handle<StepBasic_MeasureWithUnit>

        """
        return _StepRepr.StepRepr_ParallelOffset_Offset(self, *args)

    def SetOffset(self, *args) -> "void":
        r"""
        Set field offset .

        Parameters
        ----------
        theOffset: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ParallelOffset_SetOffset(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ParallelOffset_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ParallelOffset

# Register StepRepr_ParallelOffset in _StepRepr:
_StepRepr.StepRepr_ParallelOffset_swigregister(StepRepr_ParallelOffset)

class StepRepr_PerpendicularTo(StepRepr_DerivedShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_PerpendicularTo_swiginit(self, _StepRepr.new_StepRepr_PerpendicularTo(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_PerpendicularTo_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_PerpendicularTo

# Register StepRepr_PerpendicularTo in _StepRepr:
_StepRepr.StepRepr_PerpendicularTo_swigregister(StepRepr_PerpendicularTo)

class StepRepr_PromissoryUsageOccurrence(StepRepr_AssemblyComponentUsage):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_PromissoryUsageOccurrence_swiginit(self, _StepRepr.new_StepRepr_PromissoryUsageOccurrence(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_PromissoryUsageOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_PromissoryUsageOccurrence

# Register StepRepr_PromissoryUsageOccurrence in _StepRepr:
_StepRepr.StepRepr_PromissoryUsageOccurrence_swigregister(StepRepr_PromissoryUsageOccurrence)

class StepRepr_QuantifiedAssemblyComponentUsage(StepRepr_AssemblyComponentUsage):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_QuantifiedAssemblyComponentUsage_swiginit(self, _StepRepr.new_StepRepr_QuantifiedAssemblyComponentUsage(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aProductDefinitionRelationship_Id: TCollection_HAsciiString
        aProductDefinitionRelationship_Name: TCollection_HAsciiString
        hasProductDefinitionRelationship_Description: bool
        aProductDefinitionRelationship_Description: TCollection_HAsciiString
        aProductDefinitionRelationship_RelatingProductDefinition: StepBasic_ProductDefinition
        aProductDefinitionRelationship_RelatedProductDefinition: StepBasic_ProductDefinition
        hasAssemblyComponentUsage_ReferenceDesignator: bool
        aAssemblyComponentUsage_ReferenceDesignator: TCollection_HAsciiString
        aQuantity: StepBasic_MeasureWithUnit

        Returns
        -------
        None
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aProductDefinitionRelationship_Id: TCollection_HAsciiString
        aProductDefinitionRelationship_Name: TCollection_HAsciiString
        hasProductDefinitionRelationship_Description: bool
        aProductDefinitionRelationship_Description: TCollection_HAsciiString
        aProductDefinitionRelationship_RelatingProductDefinition: StepBasic_ProductDefinitionOrReference
        aProductDefinitionRelationship_RelatedProductDefinition: StepBasic_ProductDefinitionOrReference
        hasAssemblyComponentUsage_ReferenceDesignator: bool
        aAssemblyComponentUsage_ReferenceDesignator: TCollection_HAsciiString
        aQuantity: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_QuantifiedAssemblyComponentUsage_Init(self, *args)

    def Quantity(self, *args) -> "opencascade::handle< StepBasic_MeasureWithUnit >":
        r"""
        Returns field quantity.

        Returns
        -------
        opencascade::handle<StepBasic_MeasureWithUnit>

        """
        return _StepRepr.StepRepr_QuantifiedAssemblyComponentUsage_Quantity(self, *args)

    def SetQuantity(self, *args) -> "void":
        r"""
        Set field quantity.

        Parameters
        ----------
        Quantity: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_QuantifiedAssemblyComponentUsage_SetQuantity(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_QuantifiedAssemblyComponentUsage_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_QuantifiedAssemblyComponentUsage

# Register StepRepr_QuantifiedAssemblyComponentUsage in _StepRepr:
_StepRepr.StepRepr_QuantifiedAssemblyComponentUsage_swigregister(StepRepr_QuantifiedAssemblyComponentUsage)

class StepRepr_ReprItemAndLengthMeasureWithUnit(StepRepr_ReprItemAndMeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ReprItemAndLengthMeasureWithUnit_swiginit(self, _StepRepr.new_StepRepr_ReprItemAndLengthMeasureWithUnit(*args))

    def GetLengthMeasureWithUnit(self, *args) -> "opencascade::handle< StepBasic_LengthMeasureWithUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_LengthMeasureWithUnit>

        """
        return _StepRepr.StepRepr_ReprItemAndLengthMeasureWithUnit_GetLengthMeasureWithUnit(self, *args)

    def SetLengthMeasureWithUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLMWU: StepBasic_LengthMeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ReprItemAndLengthMeasureWithUnit_SetLengthMeasureWithUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ReprItemAndLengthMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ReprItemAndLengthMeasureWithUnit

# Register StepRepr_ReprItemAndLengthMeasureWithUnit in _StepRepr:
_StepRepr.StepRepr_ReprItemAndLengthMeasureWithUnit_swigregister(StepRepr_ReprItemAndLengthMeasureWithUnit)

class StepRepr_ReprItemAndPlaneAngleMeasureWithUnit(StepRepr_ReprItemAndMeasureWithUnit):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_swiginit(self, _StepRepr.new_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit(*args))

    def GetPlaneAngleMeasureWithUnit(self, *args) -> "opencascade::handle< StepBasic_PlaneAngleMeasureWithUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_PlaneAngleMeasureWithUnit>

        """
        return _StepRepr.StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_GetPlaneAngleMeasureWithUnit(self, *args)

    def SetPlaneAngleMeasureWithUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLMWU: StepBasic_PlaneAngleMeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_SetPlaneAngleMeasureWithUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ReprItemAndPlaneAngleMeasureWithUnit

# Register StepRepr_ReprItemAndPlaneAngleMeasureWithUnit in _StepRepr:
_StepRepr.StepRepr_ReprItemAndPlaneAngleMeasureWithUnit_swigregister(StepRepr_ReprItemAndPlaneAngleMeasureWithUnit)

class StepRepr_RepresentationRelationshipWithTransformation(StepRepr_ShapeRepresentationRelationship):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_RepresentationRelationshipWithTransformation_swiginit(self, _StepRepr.new_StepRepr_RepresentationRelationshipWithTransformation(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aRep1: StepRepr_Representation
        aRep2: StepRepr_Representation
        aTransf: StepRepr_Transformation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationRelationshipWithTransformation_Init(self, *args)

    def SetTransformationOperator(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aTrans: StepRepr_Transformation

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_RepresentationRelationshipWithTransformation_SetTransformationOperator(self, *args)

    def TransformationOperator(self, *args) -> "StepRepr_Transformation":
        r"""
        No available documentation.

        Returns
        -------
        StepRepr_Transformation

        """
        return _StepRepr.StepRepr_RepresentationRelationshipWithTransformation_TransformationOperator(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_RepresentationRelationshipWithTransformation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_RepresentationRelationshipWithTransformation

# Register StepRepr_RepresentationRelationshipWithTransformation in _StepRepr:
_StepRepr.StepRepr_RepresentationRelationshipWithTransformation_swigregister(StepRepr_RepresentationRelationshipWithTransformation)

class StepRepr_SpecifiedHigherUsageOccurrence(StepRepr_AssemblyComponentUsage):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_SpecifiedHigherUsageOccurrence_swiginit(self, _StepRepr.new_StepRepr_SpecifiedHigherUsageOccurrence(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aProductDefinitionRelationship_Id: TCollection_HAsciiString
        aProductDefinitionRelationship_Name: TCollection_HAsciiString
        hasProductDefinitionRelationship_Description: bool
        aProductDefinitionRelationship_Description: TCollection_HAsciiString
        aProductDefinitionRelationship_RelatingProductDefinition: StepBasic_ProductDefinition
        aProductDefinitionRelationship_RelatedProductDefinition: StepBasic_ProductDefinition
        hasAssemblyComponentUsage_ReferenceDesignator: bool
        aAssemblyComponentUsage_ReferenceDesignator: TCollection_HAsciiString
        aUpperUsage: StepRepr_AssemblyComponentUsage
        aNextUsage: StepRepr_NextAssemblyUsageOccurrence

        Returns
        -------
        None
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aProductDefinitionRelationship_Id: TCollection_HAsciiString
        aProductDefinitionRelationship_Name: TCollection_HAsciiString
        hasProductDefinitionRelationship_Description: bool
        aProductDefinitionRelationship_Description: TCollection_HAsciiString
        aProductDefinitionRelationship_RelatingProductDefinition: StepBasic_ProductDefinitionOrReference
        aProductDefinitionRelationship_RelatedProductDefinition: StepBasic_ProductDefinitionOrReference
        hasAssemblyComponentUsage_ReferenceDesignator: bool
        aAssemblyComponentUsage_ReferenceDesignator: TCollection_HAsciiString
        aUpperUsage: StepRepr_AssemblyComponentUsage
        aNextUsage: StepRepr_NextAssemblyUsageOccurrence

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_SpecifiedHigherUsageOccurrence_Init(self, *args)

    def NextUsage(self, *args) -> "opencascade::handle< StepRepr_NextAssemblyUsageOccurrence >":
        r"""
        Returns field nextusage.

        Returns
        -------
        opencascade::handle<StepRepr_NextAssemblyUsageOccurrence>

        """
        return _StepRepr.StepRepr_SpecifiedHigherUsageOccurrence_NextUsage(self, *args)

    def SetNextUsage(self, *args) -> "void":
        r"""
        Set field nextusage.

        Parameters
        ----------
        NextUsage: StepRepr_NextAssemblyUsageOccurrence

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_SpecifiedHigherUsageOccurrence_SetNextUsage(self, *args)

    def SetUpperUsage(self, *args) -> "void":
        r"""
        Set field upperusage.

        Parameters
        ----------
        UpperUsage: StepRepr_AssemblyComponentUsage

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_SpecifiedHigherUsageOccurrence_SetUpperUsage(self, *args)

    def UpperUsage(self, *args) -> "opencascade::handle< StepRepr_AssemblyComponentUsage >":
        r"""
        Returns field upperusage.

        Returns
        -------
        opencascade::handle<StepRepr_AssemblyComponentUsage>

        """
        return _StepRepr.StepRepr_SpecifiedHigherUsageOccurrence_UpperUsage(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_SpecifiedHigherUsageOccurrence_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_SpecifiedHigherUsageOccurrence

# Register StepRepr_SpecifiedHigherUsageOccurrence in _StepRepr:
_StepRepr.StepRepr_SpecifiedHigherUsageOccurrence_swigregister(StepRepr_SpecifiedHigherUsageOccurrence)

class StepRepr_Tangent(StepRepr_DerivedShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_Tangent_swiginit(self, _StepRepr.new_StepRepr_Tangent(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_Tangent_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_Tangent

# Register StepRepr_Tangent in _StepRepr:
_StepRepr.StepRepr_Tangent_swigregister(StepRepr_Tangent)

class StepRepr_ValueRange(StepRepr_CompoundRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ValueRange_swiginit(self, _StepRepr.new_StepRepr_ValueRange(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ValueRange_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ValueRange

# Register StepRepr_ValueRange in _StepRepr:
_StepRepr.StepRepr_ValueRange_swigregister(StepRepr_ValueRange)

class StepRepr_AllAroundShapeAspect(StepRepr_ContinuosShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_AllAroundShapeAspect_swiginit(self, _StepRepr.new_StepRepr_AllAroundShapeAspect(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_AllAroundShapeAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_AllAroundShapeAspect

# Register StepRepr_AllAroundShapeAspect in _StepRepr:
_StepRepr.StepRepr_AllAroundShapeAspect_swigregister(StepRepr_AllAroundShapeAspect)

class StepRepr_BetweenShapeAspect(StepRepr_ContinuosShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_BetweenShapeAspect_swiginit(self, _StepRepr.new_StepRepr_BetweenShapeAspect(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_BetweenShapeAspect_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_BetweenShapeAspect

# Register StepRepr_BetweenShapeAspect in _StepRepr:
_StepRepr.StepRepr_BetweenShapeAspect_swigregister(StepRepr_BetweenShapeAspect)

class StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_swiginit(self, _StepRepr.new_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI(*args))

    def GetLengthMeasureWithUnit(self, *args) -> "opencascade::handle< StepBasic_LengthMeasureWithUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_LengthMeasureWithUnit>

        """
        return _StepRepr.StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_GetLengthMeasureWithUnit(self, *args)

    def SetLengthMeasureWithUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLMWU: StepBasic_LengthMeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_SetLengthMeasureWithUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI

# Register StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI in _StepRepr:
_StepRepr.StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI_swigregister(StepRepr_ReprItemAndLengthMeasureWithUnitAndQRI)

class StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_swiginit(self, _StepRepr.new_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI(*args))

    def GetPlaneAngleMeasureWithUnit(self, *args) -> "opencascade::handle< StepBasic_PlaneAngleMeasureWithUnit >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_PlaneAngleMeasureWithUnit>

        """
        return _StepRepr.StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_GetPlaneAngleMeasureWithUnit(self, *args)

    def SetPlaneAngleMeasureWithUnit(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aLMWU: StepBasic_PlaneAngleMeasureWithUnit

        Returns
        -------
        None

        """
        return _StepRepr.StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_SetPlaneAngleMeasureWithUnit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI

# Register StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI in _StepRepr:
_StepRepr.StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI_swigregister(StepRepr_ReprItemAndPlaneAngleMeasureWithUnitAndQRI)

class StepRepr_ShapeRepresentationRelationshipWithTransformation(StepRepr_RepresentationRelationshipWithTransformation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepRepr.StepRepr_ShapeRepresentationRelationshipWithTransformation_swiginit(self, _StepRepr.new_StepRepr_ShapeRepresentationRelationshipWithTransformation(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_ShapeRepresentationRelationshipWithTransformation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepRepr.delete_StepRepr_ShapeRepresentationRelationshipWithTransformation

# Register StepRepr_ShapeRepresentationRelationshipWithTransformation in _StepRepr:
_StepRepr.StepRepr_ShapeRepresentationRelationshipWithTransformation_swigregister(StepRepr_ShapeRepresentationRelationshipWithTransformation)


@classnotwrapped
class StepRepr_ReprItemAndMeasureWithUnitAndQRI:
	pass


class StepRepr_HArray1OfMaterialPropertyRepresentation(StepRepr_Array1OfMaterialPropertyRepresentation, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepRepr.StepRepr_HArray1OfMaterialPropertyRepresentation_swiginit(self, _StepRepr.new_StepRepr_HArray1OfMaterialPropertyRepresentation(*args))

    def Array1(self) -> "StepRepr_Array1OfMaterialPropertyRepresentation const &":
        return _StepRepr.StepRepr_HArray1OfMaterialPropertyRepresentation_Array1(self)

    def ChangeArray1(self) -> "StepRepr_Array1OfMaterialPropertyRepresentation &":
        return _StepRepr.StepRepr_HArray1OfMaterialPropertyRepresentation_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_HArray1OfMaterialPropertyRepresentation_DownCast(t)

    __swig_destroy__ = _StepRepr.delete_StepRepr_HArray1OfMaterialPropertyRepresentation

# Register StepRepr_HArray1OfMaterialPropertyRepresentation in _StepRepr:
_StepRepr.StepRepr_HArray1OfMaterialPropertyRepresentation_swigregister(StepRepr_HArray1OfMaterialPropertyRepresentation)

class StepRepr_HArray1OfRepresentationItem(StepRepr_Array1OfRepresentationItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepRepr.StepRepr_HArray1OfRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_HArray1OfRepresentationItem(*args))

    def Array1(self) -> "StepRepr_Array1OfRepresentationItem const &":
        return _StepRepr.StepRepr_HArray1OfRepresentationItem_Array1(self)

    def ChangeArray1(self) -> "StepRepr_Array1OfRepresentationItem &":
        return _StepRepr.StepRepr_HArray1OfRepresentationItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_HArray1OfRepresentationItem_DownCast(t)

    __swig_destroy__ = _StepRepr.delete_StepRepr_HArray1OfRepresentationItem

# Register StepRepr_HArray1OfRepresentationItem in _StepRepr:
_StepRepr.StepRepr_HArray1OfRepresentationItem_swigregister(StepRepr_HArray1OfRepresentationItem)

class StepRepr_HArray1OfPropertyDefinitionRepresentation(StepRepr_Array1OfPropertyDefinitionRepresentation, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepRepr.StepRepr_HArray1OfPropertyDefinitionRepresentation_swiginit(self, _StepRepr.new_StepRepr_HArray1OfPropertyDefinitionRepresentation(*args))

    def Array1(self) -> "StepRepr_Array1OfPropertyDefinitionRepresentation const &":
        return _StepRepr.StepRepr_HArray1OfPropertyDefinitionRepresentation_Array1(self)

    def ChangeArray1(self) -> "StepRepr_Array1OfPropertyDefinitionRepresentation &":
        return _StepRepr.StepRepr_HArray1OfPropertyDefinitionRepresentation_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_HArray1OfPropertyDefinitionRepresentation_DownCast(t)

    __swig_destroy__ = _StepRepr.delete_StepRepr_HArray1OfPropertyDefinitionRepresentation

# Register StepRepr_HArray1OfPropertyDefinitionRepresentation in _StepRepr:
_StepRepr.StepRepr_HArray1OfPropertyDefinitionRepresentation_swigregister(StepRepr_HArray1OfPropertyDefinitionRepresentation)

class StepRepr_HArray1OfShapeAspect(StepRepr_Array1OfShapeAspect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepRepr.StepRepr_HArray1OfShapeAspect_swiginit(self, _StepRepr.new_StepRepr_HArray1OfShapeAspect(*args))

    def Array1(self) -> "StepRepr_Array1OfShapeAspect const &":
        return _StepRepr.StepRepr_HArray1OfShapeAspect_Array1(self)

    def ChangeArray1(self) -> "StepRepr_Array1OfShapeAspect &":
        return _StepRepr.StepRepr_HArray1OfShapeAspect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_HArray1OfShapeAspect_DownCast(t)

    __swig_destroy__ = _StepRepr.delete_StepRepr_HArray1OfShapeAspect

# Register StepRepr_HArray1OfShapeAspect in _StepRepr:
_StepRepr.StepRepr_HArray1OfShapeAspect_swigregister(StepRepr_HArray1OfShapeAspect)

class StepRepr_HSequenceOfRepresentationItem(StepRepr_SequenceOfRepresentationItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepRepr.StepRepr_HSequenceOfRepresentationItem_swiginit(self, _StepRepr.new_StepRepr_HSequenceOfRepresentationItem(*args))

    def Sequence(self) -> "StepRepr_SequenceOfRepresentationItem const &":
        return _StepRepr.StepRepr_HSequenceOfRepresentationItem_Sequence(self)

    def Append(self, *args) -> "void":
        return _StepRepr.StepRepr_HSequenceOfRepresentationItem_Append(self, *args)

    def ChangeSequence(self) -> "StepRepr_SequenceOfRepresentationItem &":
        return _StepRepr.StepRepr_HSequenceOfRepresentationItem_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_HSequenceOfRepresentationItem_DownCast(t)

    __swig_destroy__ = _StepRepr.delete_StepRepr_HSequenceOfRepresentationItem

# Register StepRepr_HSequenceOfRepresentationItem in _StepRepr:
_StepRepr.StepRepr_HSequenceOfRepresentationItem_swigregister(StepRepr_HSequenceOfRepresentationItem)

class StepRepr_HSequenceOfMaterialPropertyRepresentation(StepRepr_SequenceOfMaterialPropertyRepresentation, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepRepr.StepRepr_HSequenceOfMaterialPropertyRepresentation_swiginit(self, _StepRepr.new_StepRepr_HSequenceOfMaterialPropertyRepresentation(*args))

    def Sequence(self) -> "StepRepr_SequenceOfMaterialPropertyRepresentation const &":
        return _StepRepr.StepRepr_HSequenceOfMaterialPropertyRepresentation_Sequence(self)

    def Append(self, *args) -> "void":
        return _StepRepr.StepRepr_HSequenceOfMaterialPropertyRepresentation_Append(self, *args)

    def ChangeSequence(self) -> "StepRepr_SequenceOfMaterialPropertyRepresentation &":
        return _StepRepr.StepRepr_HSequenceOfMaterialPropertyRepresentation_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepRepr_HSequenceOfMaterialPropertyRepresentation_DownCast(t)

    __swig_destroy__ = _StepRepr.delete_StepRepr_HSequenceOfMaterialPropertyRepresentation

# Register StepRepr_HSequenceOfMaterialPropertyRepresentation in _StepRepr:
_StepRepr.StepRepr_HSequenceOfMaterialPropertyRepresentation_swigregister(StepRepr_HSequenceOfMaterialPropertyRepresentation)





